rm(list = ls())
######### library packages ###########
library(maptools)
library(plotbiomes)
library(RColorBrewer)
library(rgdal)
library(sp)
library(sf)
library(raster)
library(grid)
library(mapproj)
library(legendMap)
library(ggplot2)
library(lme4)
library(lmerTest)
library(Hmisc)
library(data.table)
library(car)
library(MuMIn)
library(readxl)
library(plyr)
library(dplyr)
library(scales)
library(grid)
library(gridExtra)
library(ggpubr)
library(tidyr) ## split data etc.

# set working directory
## automatically setting working directory (where you open this R file, your working directory will be setted there)
setwd(dirname(rstudioapi::getActiveDocumentContext()$path))

d1<-read.csv("Total.csv")

crdref <- CRS('+proj=longlat +datum=WGS84')
China=readOGR(dsn="D:/Rroad/Meta-N", layer="bou2_4p") 
South=readOGR(dsn = "D:/Rroad/Meta-N",layer="Nine segments",use_iconv = TRUE, encoding="UTF-8")
Island=readOGR(dsn = "D:/Rroad/Meta-N",layer="South sea",use_iconv = TRUE, encoding="UTF-8")
proj4string(China)=crdref
Figure1a<-ggplot() + 
  geom_polygon(data = China, aes(x = long, y = lat,group=group),fill="white",colour="black") +
  geom_polygon(data = South, aes(x = long, y = lat,group=group),fill="white",colour="black") +
  coord_map()+
  scale_bar(lon =75, lat = 55, 
            distance_lon = 500, distance_lat = 100, distance_legend = 200, 
            dist_unit = "km", orientation = T,
            arrow_length = 400, arrow_distance = 300, arrow_north_size = 5)+
  geom_point(data = d1,aes(y = d1$latitude, x = d1$longitude,col=Ecosystem, Shape=Ecosystem),size=3)+
  scale_shape_manual(values =c(21:24))+
  guides(fill=guide_legend(title=" Ecosystem", ncol=1, byrow=TRUE),size=F)
Figure1a

Figure1b <-whittaker_base_plot()+
  fill_palette("BrBG")+
  theme(legend.position=c(0.25,0.67))+
  theme(legend.background = element_blank())+
  labs(fill="Whittaker biomes")+
  geom_point(data = d1,aes(x=MAT,y=MAP_cm),shape=21,size=3, fill="red3")+
  theme_bw()
Figure1b 

dL<-subset(d1, EC=="Leaf")
dST<-subset(d1, EC=="Stem")
dR<-subset(d1, EC=="Root")
dLi<-subset(d1, EC=="Litter")
dS<-subset(d1, EC=="Soil")

dL
dST
dR
dLi
dS

#####Alternative models
####scaled estimates for both N and ED coefficients allowing to determine main effects and slopes at the same time
############# N model ##################
############## N + log (ED) #############
mFA1N<-lmer(yi_N~scale(N)+scale(log(ED))+(1|reference), weights=Wi_N, dL)
mFA2N<-lmer(yi_N~scale(N)+scale(log(ED))+(1|reference), weights=Wi_N, dST)
mFA3N<-lmer(yi_N~scale(N)+scale(log(ED))+(1|reference), weights=Wi_N, dR)
mFA4N<-lmer(yi_N~scale(N)+scale(log(ED))+(1|reference), weights=Wi_N, dLi)
mFA5N<-lmer(yi_N~scale(N)+scale(log(ED))+(1|reference), weights=Wi_N, dS)

############ N + ED ################
mFB1N<-lmer(yi_N~scale(N)+scale(ED)+(1|reference), weights=Wi_N, dL)
mFB2N<-lmer(yi_N~scale(N)+scale(ED)+(1|reference), weights=Wi_N, dST)
mFB3N<-lmer(yi_N~scale(N)+scale(ED)+(1|reference), weights=Wi_N, dR)
mFB4N<-lmer(yi_N~scale(N)+scale(ED)+(1|reference), weights=Wi_N, dLi)
mFB5N<-lmer(yi_N~scale(N)+scale(ED)+(1|reference), weights=Wi_N, dS)

############## log (N) + ED #############
mFC1N<-lmer(yi_N~scale(log(N))+scale(ED)+(1|reference), weights=Wi_N, dL)
mFC2N<-lmer(yi_N~scale(log(N))+scale(ED)+(1|reference), weights=Wi_N, dST)
mFC3N<-lmer(yi_N~scale(log(N))+scale(ED)+(1|reference), weights=Wi_N, dR)
mFC4N<-lmer(yi_N~scale(log(N))+scale(ED)+(1|reference), weights=Wi_N, dLi)
mFC5N<-lmer(yi_N~scale(log(N))+scale(ED)+(1|reference), weights=Wi_N, dS)

############## log (N) + log (ED) #############
mFD1N<-lmer(yi_N~scale(log(N))+scale(log(ED))+(1|reference), weights=Wi_N, dL)
mFD2N<-lmer(yi_N~scale(log(N))+scale(log(ED))+(1|reference), weights=Wi_N, dST)
mFD3N<-lmer(yi_N~scale(log(N))+scale(log(ED))+(1|reference), weights=Wi_N, dR)
mFD4N<-lmer(yi_N~scale(log(N))+scale(log(ED))+(1|reference), weights=Wi_N, dLi)
mFD5N<-lmer(yi_N~scale(log(N))+scale(log(ED))+(1|reference), weights=Wi_N, dS)

############## N * log (ED) #############
mFE1N<-lmer(yi_N~scale(log(N))*scale(log(ED))+(1|reference), weights=Wi_N, dL)
mFE2N<-lmer(yi_N~scale(log(N))*scale(log(ED))+(1|reference), weights=Wi_N, dST)
mFE3N<-lmer(yi_N~scale(log(N))*scale(log(ED))+(1|reference), weights=Wi_N, dR)
mFE4N<-lmer(yi_N~scale(log(N))*scale(log(ED))+(1|reference), weights=Wi_N, dLi)
mFE5N<-lmer(yi_N~scale(log(N))*scale(log(ED))+(1|reference), weights=Wi_N, dS)

tSAN1<- rbind(AIC(mFA1N),AIC(mFA2N),AIC(mFA3N),AIC(mFA4N),AIC(mFA5N))
tSBN1<- rbind(AIC(mFB1N),AIC(mFB2N),AIC(mFB3N),AIC(mFB4N),AIC(mFB5N))
tSCN1<- rbind(AIC(mFC1N),AIC(mFC2N),AIC(mFC3N),AIC(mFC4N),AIC(mFC5N))
tSDN1<- rbind(AIC(mFD1N),AIC(mFD2N),AIC(mFD3N),AIC(mFD4N),AIC(mFD5N))
tSEN1<- rbind(AIC(mFE1N),AIC(mFE2N),AIC(mFE3N),AIC(mFE4N),AIC(mFE5N))
tSIN<-data.frame(cbind(tSAN1,tSBN1,tSCN1,tSDN1,tSEN1))
write.csv(tSIN,"tSIN.csv")


############# P model ##################
############## N + log (ED) #############
mFA1P<-lmer(yi_P~scale(N)+scale(log(ED))+(1|reference), weights=Wi_P, dL)
mFA2P<-lmer(yi_P~scale(N)+scale(log(ED))+(1|reference), weights=Wi_P, dST)
mFA3P<-lmer(yi_P~scale(N)+scale(log(ED))+(1|reference), weights=Wi_P, dR)
mFA4P<-lmer(yi_P~scale(N)+scale(log(ED))+(1|reference), weights=Wi_P, dLi)
mFA5P<-lmer(yi_P~scale(N)+scale(log(ED))+(1|reference), weights=Wi_P, dS)

############ N + ED ################
mFB1P<-lmer(yi_P~scale(N)+scale(ED)+(1|reference), weights=Wi_P, dL)
mFB2P<-lmer(yi_P~scale(N)+scale(ED)+(1|reference), weights=Wi_P, dST)
mFB3P<-lmer(yi_P~scale(N)+scale(ED)+(1|reference), weights=Wi_P, dR)
mFB4P<-lmer(yi_P~scale(N)+scale(ED)+(1|reference), weights=Wi_P, dLi)
mFB5P<-lmer(yi_P~scale(N)+scale(ED)+(1|reference), weights=Wi_P, dS)

############## log (N) + ED #############
mFC1P<-lmer(yi_P~scale(log(N))+scale(ED)+(1|reference), weights=Wi_P, dL)
mFC2P<-lmer(yi_P~scale(log(N))+scale(ED)+(1|reference), weights=Wi_P, dST)
mFC3P<-lmer(yi_P~scale(log(N))+scale(ED)+(1|reference), weights=Wi_P, dR)
mFC4P<-lmer(yi_P~scale(log(N))+scale(ED)+(1|reference), weights=Wi_P, dLi)
mFC5P<-lmer(yi_P~scale(log(N))+scale(ED)+(1|reference), weights=Wi_P, dS)

############## log (N) + log (ED) #############
mFD1P<-lmer(yi_P~scale(log(N))+scale(log(ED))+(1|reference), weights=Wi_P, dL)
mFD2P<-lmer(yi_P~scale(log(N))+scale(log(ED))+(1|reference), weights=Wi_P, dST)
mFD3P<-lmer(yi_P~scale(log(N))+scale(log(ED))+(1|reference), weights=Wi_P, dR)
mFD4P<-lmer(yi_P~scale(log(N))+scale(log(ED))+(1|reference), weights=Wi_P, dLi)
mFD5P<-lmer(yi_P~scale(log(N))+scale(log(ED))+(1|reference), weights=Wi_P, dS)

############## N * log (ED) #############
mFE1P<-lmer(yi_P~scale(log(N))*scale(log(ED))+(1|reference), weights=Wi_P, dL)
mFE2P<-lmer(yi_P~scale(log(N))*scale(log(ED))+(1|reference), weights=Wi_P, dST)
mFE3P<-lmer(yi_P~scale(log(N))*scale(log(ED))+(1|reference), weights=Wi_P, dR)
mFE4P<-lmer(yi_P~scale(log(N))*scale(log(ED))+(1|reference), weights=Wi_P, dLi)
mFE5P<-lmer(yi_P~scale(log(N))*scale(log(ED))+(1|reference), weights=Wi_P, dS)

tSAP1<- rbind(AIC(mFA1P),AIC(mFA2P),AIC(mFA3P),AIC(mFA4P),AIC(mFA5P))
tSBP1<- rbind(AIC(mFB1P),AIC(mFB2P),AIC(mFB3P),AIC(mFB4P),AIC(mFB5P))
tSCP1<- rbind(AIC(mFC1P),AIC(mFC2P),AIC(mFC3P),AIC(mFC4P),AIC(mFC5P))
tSDP1<- rbind(AIC(mFD1P),AIC(mFD2P),AIC(mFD3P),AIC(mFD4P),AIC(mFD5P))
tSEP1<- rbind(AIC(mFE1P),AIC(mFE2P),AIC(mFE3P),AIC(mFE4P),AIC(mFE5P))
tSIP<-data.frame(cbind(tSAP1,tSBP1,tSCP1,tSDP1,tSEP1))
write.csv(tSIP,"tSIP.csv")

############# NP model ##################
############## N + log (ED) #############
mFA1NP<-lmer(yi_NP~scale(N)+scale(log(ED))+(1|reference), weights=Wi_NP, dL)
mFA2NP<-lmer(yi_NP~scale(N)+scale(log(ED))+(1|reference), weights=Wi_NP, dST)
mFA3NP<-lmer(yi_NP~scale(N)+scale(log(ED))+(1|reference), weights=Wi_NP, dR)
mFA4NP<-lmer(yi_NP~scale(N)+scale(log(ED))+(1|reference), weights=Wi_NP, dLi)
mFA5NP<-lmer(yi_NP~scale(N)+scale(log(ED))+(1|reference), weights=Wi_NP, dS)

############ N + ED ################
mFB1NP<-lmer(yi_NP~scale(N)+scale(ED)+(1|reference), weights=Wi_NP, dL)
mFB2NP<-lmer(yi_NP~scale(N)+scale(ED)+(1|reference), weights=Wi_NP, dST)
mFB3NP<-lmer(yi_NP~scale(N)+scale(ED)+(1|reference), weights=Wi_NP, dR)
mFB4NP<-lmer(yi_NP~scale(N)+scale(ED)+(1|reference), weights=Wi_NP, dLi)
mFB5NP<-lmer(yi_NP~scale(N)+scale(ED)+(1|reference), weights=Wi_NP, dS)

############## log (N) + ED #############
mFC1NP<-lmer(yi_NP~scale(log(N))+scale(ED)+(1|reference), weights=Wi_NP, dL)
mFC2NP<-lmer(yi_NP~scale(log(N))+scale(ED)+(1|reference), weights=Wi_NP, dST)
mFC3NP<-lmer(yi_NP~scale(log(N))+scale(ED)+(1|reference), weights=Wi_NP, dR)
mFC4NP<-lmer(yi_NP~scale(log(N))+scale(ED)+(1|reference), weights=Wi_NP, dLi)
mFC5NP<-lmer(yi_NP~scale(log(N))+scale(ED)+(1|reference), weights=Wi_NP, dS)

############## log (N) + log (ED) #############
mFD1NP<-lmer(yi_NP~scale(log(N))+scale(log(ED))+(1|reference), weights=Wi_NP, dL)
mFD2NP<-lmer(yi_NP~scale(log(N))+scale(log(ED))+(1|reference), weights=Wi_NP, dST)
mFD3NP<-lmer(yi_NP~scale(log(N))+scale(log(ED))+(1|reference), weights=Wi_NP, dR)
mFD4NP<-lmer(yi_NP~scale(log(N))+scale(log(ED))+(1|reference), weights=Wi_NP, dLi)
mFD5NP<-lmer(yi_NP~scale(log(N))+scale(log(ED))+(1|reference), weights=Wi_NP, dS)

############## N * log (ED) #############
mFE1NP<-lmer(yi_NP~scale(log(N))*scale(log(ED))+(1|reference), weights=Wi_NP, dL)
mFE2NP<-lmer(yi_NP~scale(log(N))*scale(log(ED))+(1|reference), weights=Wi_NP, dST)
mFE3NP<-lmer(yi_NP~scale(log(N))*scale(log(ED))+(1|reference), weights=Wi_NP, dR)
mFE4NP<-lmer(yi_NP~scale(log(N))*scale(log(ED))+(1|reference), weights=Wi_NP, dLi)
mFE5NP<-lmer(yi_NP~scale(log(N))*scale(log(ED))+(1|reference), weights=Wi_NP, dS)

tSANP1<- rbind(AIC(mFA1NP),AIC(mFA2NP),AIC(mFA3NP),AIC(mFA4NP),AIC(mFA5NP))
tSBNP1<- rbind(AIC(mFB1NP),AIC(mFB2NP),AIC(mFB3NP),AIC(mFB4NP),AIC(mFB5NP))
tSCNP1<- rbind(AIC(mFC1NP),AIC(mFC2NP),AIC(mFC3NP),AIC(mFC4NP),AIC(mFC5NP))
tSDNP1<- rbind(AIC(mFD1NP),AIC(mFD2NP),AIC(mFD3NP),AIC(mFD4NP),AIC(mFD5NP))
tSENP1<- rbind(AIC(mFE1NP),AIC(mFE2NP),AIC(mFE3NP),AIC(mFE4NP),AIC(mFE5NP))
tSINP<-data.frame(cbind(tSANP1,tSBNP1,tSCNP1,tSDNP1,tSENP1))
write.csv(tSINP,"tSINP.csv")
  
########## model selection with GF ##########
############## N ###############
############## Ecosystem ###########
############## log (N) + ED #############
############# model 1 ###########
Eco11N<-lmer(yi_N~scale(log(N))+scale(ED)+Ecosystem+(1|reference), weights=Wi_N, dL)
Eco12N<-lmer(yi_N~scale(log(N))+scale(ED)+Ecosystem+(1|reference), weights=Wi_N, dST)
Eco13N<-lmer(yi_N~scale(log(N))+scale(ED)+Ecosystem+(1|reference), weights=Wi_N, dR)
Eco14N<-lmer(yi_N~scale(log(N))+scale(ED)+Ecosystem+(1|reference), weights=Wi_N, dLi)
Eco15N<-lmer(yi_N~scale(log(N))+scale(ED)+Ecosystem+(1|reference), weights=Wi_N, dS)
############ model 2 ################
Eco21N<-lmer(yi_N~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+(1|reference), weights=Wi_N, dL)
Eco22N<-lmer(yi_N~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+(1|reference), weights=Wi_N, dST)
Eco23N<-lmer(yi_N~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+(1|reference), weights=Wi_N, dR)
Eco24N<-lmer(yi_N~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+(1|reference), weights=Wi_N, dLi)
Eco25N<-lmer(yi_N~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+(1|reference), weights=Wi_N, dS)
############ model 3 ################
Eco31N<-lmer(yi_N~scale(log(N))+scale(ED)+Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_N, dL)
Eco32N<-lmer(yi_N~scale(log(N))+scale(ED)+Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_N, dST)
Eco33N<-lmer(yi_N~scale(log(N))+scale(ED)+Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_N, dR)
Eco34N<-lmer(yi_N~scale(log(N))+scale(ED)+Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_N, dLi)
Eco35N<-lmer(yi_N~scale(log(N))+scale(ED)+Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_N, dS)
############ model 4 ################
Eco41N<-lmer(yi_N~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_N, dL)
Eco42N<-lmer(yi_N~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_N, dST)
Eco43N<-lmer(yi_N~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_N, dR)
Eco44N<-lmer(yi_N~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_N, dLi)
Eco45N<-lmer(yi_N~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_N, dS)

EcoAN1<- rbind(AIC(Eco11N),AIC(Eco12N),AIC(Eco13N),AIC(Eco14N),AIC(Eco15N))
EcoBN1<- rbind(AIC(Eco21N),AIC(Eco22N),AIC(Eco23N),AIC(Eco24N),AIC(Eco25N))
EcoCN1<- rbind(AIC(Eco31N),AIC(Eco32N),AIC(Eco33N),AIC(Eco34N),AIC(Eco35N))
EcoDN1<- rbind(AIC(Eco41N),AIC(Eco42N),AIC(Eco43N),AIC(Eco44N),AIC(Eco45N))

EcoN<-data.frame(cbind(EcoAN1,EcoBN1,EcoCN1,EcoDN1))
write.csv(EcoN,"EcoN.csv")

############## MAT ###########
############## log (N) + ED #############
############# model 1 ###########

MAT11N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAT)+(1|reference), weights=Wi_N, dL)
MAT12N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAT)+(1|reference), weights=Wi_N, dST)
MAT13N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAT)+(1|reference), weights=Wi_N, dR)
MAT14N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAT)+(1|reference), weights=Wi_N, dLi)
MAT15N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAT)+(1|reference), weights=Wi_N, dS)

############# model 2 ###########
MAT21N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAT)+scale(log(N))*scale(MAT)+(1|reference), weights=Wi_N, dL)
MAT22N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAT)+scale(log(N))*scale(MAT)+(1|reference), weights=Wi_N, dST)
MAT23N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAT)+scale(log(N))*scale(MAT)+(1|reference), weights=Wi_N, dR)
MAT24N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAT)+scale(log(N))*scale(MAT)+(1|reference), weights=Wi_N, dLi)
MAT25N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAT)+scale(log(N))*scale(MAT)+(1|reference), weights=Wi_N, dS)

############# model 3 ###########

MAT31N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAT)+scale(log(ED))*scale(MAT)+(1|reference), weights=Wi_N, dL)
MAT32N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAT)+scale(log(ED))*scale(MAT)+(1|reference), weights=Wi_N, dST)
MAT33N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAT)+scale(log(ED))*scale(MAT)+(1|reference), weights=Wi_N, dR)
MAT34N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAT)+scale(log(ED))*scale(MAT)+(1|reference), weights=Wi_N, dLi)
MAT35N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAT)+scale(log(ED))*scale(MAT)+(1|reference), weights=Wi_N, dS)

############# model 4 ###########

MAT41N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAT)+scale(log(ED))*scale(MAT)+scale(log(N))*scale(MAT)+(1|reference), weights=Wi_N, dL)
MAT42N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAT)+scale(log(ED))*scale(MAT)+scale(log(N))*scale(MAT)+(1|reference), weights=Wi_N, dST)
MAT43N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAT)+scale(log(ED))*scale(MAT)+scale(log(N))*scale(MAT)+(1|reference), weights=Wi_N, dR)
MAT44N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAT)+scale(log(ED))*scale(MAT)+scale(log(N))*scale(MAT)+(1|reference), weights=Wi_N, dLi)
MAT45N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAT)+scale(log(ED))*scale(MAT)+scale(log(N))*scale(MAT)+(1|reference), weights=Wi_N, dS)

MATAN1<- rbind(AIC(MAT11N),AIC(MAT12N),AIC(MAT13N),AIC(MAT14N),AIC(MAT15N))
MATBN1<- rbind(AIC(MAT21N),AIC(MAT22N),AIC(MAT23N),AIC(MAT24N),AIC(MAT25N))
MATCN1<- rbind(AIC(MAT31N),AIC(MAT32N),AIC(MAT33N),AIC(MAT34N),AIC(MAT35N))
MATDN1<- rbind(AIC(MAT41N),AIC(MAT42N),AIC(MAT43N),AIC(MAT44N),AIC(MAT45N))

MATN<-data.frame(cbind(MATAN1,MATBN1,MATCN1,MATDN1))
write.csv(MATN,"MATN.csv")


############## MAP ###########
############## log (N) + ED #############
############# model 1 ###########

MAP11N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAP)+(1|reference), weights=Wi_N, dL)
MAP12N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAP)+(1|reference), weights=Wi_N, dST)
MAP13N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAP)+(1|reference), weights=Wi_N, dR)
MAP14N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAP)+(1|reference), weights=Wi_N, dLi)
MAP15N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAP)+(1|reference), weights=Wi_N, dS)

############# model 2 ###########
MAP21N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAP)+scale(log(N))*scale(MAP)+(1|reference), weights=Wi_N, dL)
MAP22N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAP)+scale(log(N))*scale(MAP)+(1|reference), weights=Wi_N, dST)
MAP23N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAP)+scale(log(N))*scale(MAP)+(1|reference), weights=Wi_N, dR)
MAP24N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAP)+scale(log(N))*scale(MAP)+(1|reference), weights=Wi_N, dLi)
MAP25N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAP)+scale(log(N))*scale(MAP)+(1|reference), weights=Wi_N, dS)

############# model 3 ###########

MAP31N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAP)+scale(log(ED))*scale(MAP)+(1|reference), weights=Wi_N, dL)
MAP32N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAP)+scale(log(ED))*scale(MAP)+(1|reference), weights=Wi_N, dST)
MAP33N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAP)+scale(log(ED))*scale(MAP)+(1|reference), weights=Wi_N, dR)
MAP34N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAP)+scale(log(ED))*scale(MAP)+(1|reference), weights=Wi_N, dLi)
MAP35N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAP)+scale(log(ED))*scale(MAP)+(1|reference), weights=Wi_N, dS)

############# model 4 ###########

MAP41N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAP)+scale(log(ED))*scale(MAP)+scale(log(N))*scale(MAP)+(1|reference), weights=Wi_N, dL)
MAP42N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAP)+scale(log(ED))*scale(MAP)+scale(log(N))*scale(MAP)+(1|reference), weights=Wi_N, dST)
MAP43N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAP)+scale(log(ED))*scale(MAP)+scale(log(N))*scale(MAP)+(1|reference), weights=Wi_N, dR)
MAP44N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAP)+scale(log(ED))*scale(MAP)+scale(log(N))*scale(MAP)+(1|reference), weights=Wi_N, dLi)
MAP45N<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAP)+scale(log(ED))*scale(MAP)+scale(log(N))*scale(MAP)+(1|reference), weights=Wi_N, dS)

MAPAN1<- rbind(AIC(MAP11N),AIC(MAP12N),AIC(MAP13N),AIC(MAP14N),AIC(MAP15N))
MAPBN1<- rbind(AIC(MAP21N),AIC(MAP22N),AIC(MAP23N),AIC(MAP24N),AIC(MAP25N))
MAPCN1<- rbind(AIC(MAP31N),AIC(MAP32N),AIC(MAP33N),AIC(MAP34N),AIC(MAP35N))
MAPDN1<- rbind(AIC(MAP41N),AIC(MAP42N),AIC(MAP43N),AIC(MAP44N),AIC(MAP45N))

MAPN<-data.frame(cbind(MAPAN1,MAPBN1,MAPCN1,MAPDN1))
write.csv(MAPN,"MAPN.csv")







########## model selection with GF ##########
############## P ###############
############## Ecosystem ###########
############## log (N) + ED #############
############# model 1 ###########
Eco11P<-lmer(yi_P~scale(log(N))+scale(ED)+Ecosystem+(1|reference), weights=Wi_P, dL)
Eco12P<-lmer(yi_P~scale(log(N))+scale(ED)+Ecosystem+(1|reference), weights=Wi_P, dST)
Eco13P<-lmer(yi_P~scale(log(N))+scale(ED)+Ecosystem+(1|reference), weights=Wi_P, dR)
Eco14P<-lmer(yi_P~scale(log(N))+scale(ED)+Ecosystem+(1|reference), weights=Wi_P, dLi)
Eco15P<-lmer(yi_P~scale(log(N))+scale(ED)+Ecosystem+(1|reference), weights=Wi_P, dS)
############ model 2 ################
Eco21P<-lmer(yi_P~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+(1|reference), weights=Wi_P, dL)
Eco22P<-lmer(yi_P~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+(1|reference), weights=Wi_P, dST)
Eco23P<-lmer(yi_P~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+(1|reference), weights=Wi_P, dR)
Eco24P<-lmer(yi_P~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+(1|reference), weights=Wi_P, dLi)
Eco25P<-lmer(yi_P~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+(1|reference), weights=Wi_P, dS)
############ model 3 ################
Eco31P<-lmer(yi_P~scale(log(N))+scale(ED)+Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_P, dL)
Eco32P<-lmer(yi_P~scale(log(N))+scale(ED)+Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_P, dST)
Eco33P<-lmer(yi_P~scale(log(N))+scale(ED)+Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_P, dR)
Eco34P<-lmer(yi_P~scale(log(N))+scale(ED)+Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_P, dLi)
Eco35P<-lmer(yi_P~scale(log(N))+scale(ED)+Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_P, dS)
############ model 4 ################
Eco41P<-lmer(yi_P~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_P, dL)
Eco42P<-lmer(yi_P~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_P, dST)
Eco43P<-lmer(yi_P~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_P, dR)
Eco44P<-lmer(yi_P~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_P, dLi)
Eco45P<-lmer(yi_P~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_P, dS)

EcoAP1<- rbind(AIC(Eco11P),AIC(Eco12P),AIC(Eco13P),AIC(Eco14P),AIC(Eco15P))
EcoBP1<- rbind(AIC(Eco21P),AIC(Eco22P),AIC(Eco23P),AIC(Eco24P),AIC(Eco25P))
EcoCP1<- rbind(AIC(Eco31P),AIC(Eco32P),AIC(Eco33P),AIC(Eco34P),AIC(Eco35P))
EcoDP1<- rbind(AIC(Eco41P),AIC(Eco42P),AIC(Eco43P),AIC(Eco44P),AIC(Eco45P))

EcoP<-data.frame(cbind(EcoAP1,EcoBP1,EcoCP1,EcoDP1))
write.csv(EcoP,"EcoP.csv")

############## MAT ###########
############## log (N) + ED #############
############# model 1 ###########

MAT11P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAT)+(1|reference), weights=Wi_P, dL)
MAT12P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAT)+(1|reference), weights=Wi_P, dST)
MAT13P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAT)+(1|reference), weights=Wi_P, dR)
MAT14P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAT)+(1|reference), weights=Wi_P, dLi)
MAT15P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAT)+(1|reference), weights=Wi_P, dS)

############# model 2 ###########
MAT21P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAT)+scale(log(N))*scale(MAT)+(1|reference), weights=Wi_P, dL)
MAT22P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAT)+scale(log(N))*scale(MAT)+(1|reference), weights=Wi_P, dST)
MAT23P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAT)+scale(log(N))*scale(MAT)+(1|reference), weights=Wi_P, dR)
MAT24P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAT)+scale(log(N))*scale(MAT)+(1|reference), weights=Wi_P, dLi)
MAT25P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAT)+scale(log(N))*scale(MAT)+(1|reference), weights=Wi_P, dS)

############# model 3 ###########

MAT31P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAT)+scale(log(ED))*scale(MAT)+(1|reference), weights=Wi_P, dL)
MAT32P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAT)+scale(log(ED))*scale(MAT)+(1|reference), weights=Wi_P, dST)
MAT33P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAT)+scale(log(ED))*scale(MAT)+(1|reference), weights=Wi_P, dR)
MAT34P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAT)+scale(log(ED))*scale(MAT)+(1|reference), weights=Wi_P, dLi)
MAT35P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAT)+scale(log(ED))*scale(MAT)+(1|reference), weights=Wi_P, dS)

############# model 4 ###########

MAT41P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAT)+(1|reference)+scale(log(ED))*scale(MAT)+scale(log(N))*scale(MAT), weights=Wi_P, dL)
MAT42P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAT)+(1|reference)+scale(log(ED))*scale(MAT)+scale(log(N))*scale(MAT), weights=Wi_P, dST)
MAT43P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAT)+(1|reference)+scale(log(ED))*scale(MAT)+scale(log(N))*scale(MAT), weights=Wi_P, dR)
MAT44P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAT)+(1|reference)+scale(log(ED))*scale(MAT)+scale(log(N))*scale(MAT), weights=Wi_P, dLi)
MAT45P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAT)+(1|reference)+scale(log(ED))*scale(MAT)+scale(log(N))*scale(MAT), weights=Wi_P, dS)

MATAP1<- rbind(AIC(MAT11P),AIC(MAT12P),AIC(MAT13P),AIC(MAT14P),AIC(MAT15P))
MATBP1<- rbind(AIC(MAT21P),AIC(MAT22P),AIC(MAT23P),AIC(MAT24P),AIC(MAT25P))
MATCP1<- rbind(AIC(MAT31P),AIC(MAT32P),AIC(MAT33P),AIC(MAT34P),AIC(MAT35P))
MATDP1<- rbind(AIC(MAT41P),AIC(MAT42P),AIC(MAT43P),AIC(MAT44P),AIC(MAT45P))

MATP<-data.frame(cbind(MATAP1,MATBP1,MATCP1,MATDP1))
write.csv(MATP,"MATP.csv")


############## MAP ###########
############## log (N) + ED #############
############# model 1 ###########

MAP11P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAP)+(1|reference), weights=Wi_P, dL)
MAP12P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAP)+(1|reference), weights=Wi_P, dST)
MAP13P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAP)+(1|reference), weights=Wi_P, dR)
MAP14P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAP)+(1|reference), weights=Wi_P, dLi)
MAP15P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAP)+(1|reference), weights=Wi_P, dS)

############# model 2 ###########
MAP21P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAP)+scale(log(N))*scale(MAP)+(1|reference), weights=Wi_P, dL)
MAP22P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAP)+scale(log(N))*scale(MAP)+(1|reference), weights=Wi_P, dST)
MAP23P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAP)+scale(log(N))*scale(MAP)+(1|reference), weights=Wi_P, dR)
MAP24P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAP)+scale(log(N))*scale(MAP)+(1|reference), weights=Wi_P, dLi)
MAP25P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAP)+scale(log(N))*scale(MAP)+(1|reference), weights=Wi_P, dS)

############# model 3 ###########

MAP31P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAP)+scale(log(ED))*scale(MAP)+(1|reference), weights=Wi_P, dL)
MAP32P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAP)+scale(log(ED))*scale(MAP)+(1|reference), weights=Wi_P, dST)
MAP33P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAP)+scale(log(ED))*scale(MAP)+(1|reference), weights=Wi_P, dR)
MAP34P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAP)+scale(log(ED))*scale(MAP)+(1|reference), weights=Wi_P, dLi)
MAP35P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAP)+scale(log(ED))*scale(MAP)+(1|reference), weights=Wi_P, dS)

############# model 4 ###########

MAP41P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAP)+(1|reference)+scale(log(ED))*scale(MAP)+scale(log(N))*scale(MAP), weights=Wi_P, dL)
MAP42P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAP)+(1|reference)+scale(log(ED))*scale(MAP)+scale(log(N))*scale(MAP), weights=Wi_P, dST)
MAP43P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAP)+(1|reference)+scale(log(ED))*scale(MAP)+scale(log(N))*scale(MAP), weights=Wi_P, dR)
MAP44P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAP)+(1|reference)+scale(log(ED))*scale(MAP)+scale(log(N))*scale(MAP), weights=Wi_P, dLi)
MAP45P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAP)+(1|reference)+scale(log(ED))*scale(MAP)+scale(log(N))*scale(MAP), weights=Wi_P, dS)

MAPAP1<- rbind(AIC(MAP11P),AIC(MAP12P),AIC(MAP13P),AIC(MAP14P),AIC(MAP15P))
MAPBP1<- rbind(AIC(MAP21P),AIC(MAP22P),AIC(MAP23P),AIC(MAP24P),AIC(MAP25P))
MAPCP1<- rbind(AIC(MAP31P),AIC(MAP32P),AIC(MAP33P),AIC(MAP34P),AIC(MAP35P))
MAPDP1<- rbind(AIC(MAP41P),AIC(MAP42P),AIC(MAP43P),AIC(MAP44P),AIC(MAP45P))

MAPP<-data.frame(cbind(MAPAP1,MAPBP1,MAPCP1,MAPDP1))
write.csv(MAPP,"MAPP.csv")


############## NP ###############
############## Ecosystem ###########
############## log (N) + ED #############
############# model 1 ###########
Eco11NP<-lmer(yi_NP~scale(log(N))+scale(ED)+Ecosystem+(1|reference), weights=Wi_NP, dL)
Eco12NP<-lmer(yi_NP~scale(log(N))+scale(ED)+Ecosystem+(1|reference), weights=Wi_NP, dST)
Eco13NP<-lmer(yi_NP~scale(log(N))+scale(ED)+Ecosystem+(1|reference), weights=Wi_NP, dR)
Eco14NP<-lmer(yi_NP~scale(log(N))+scale(ED)+Ecosystem+(1|reference), weights=Wi_NP, dLi)
Eco15NP<-lmer(yi_NP~scale(log(N))+scale(ED)+Ecosystem+(1|reference), weights=Wi_NP, dS)
############ model 2 ################
Eco21NP<-lmer(yi_NP~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+(1|reference), weights=Wi_NP, dL)
Eco22NP<-lmer(yi_NP~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+(1|reference), weights=Wi_NP, dST)
Eco23NP<-lmer(yi_NP~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+(1|reference), weights=Wi_NP, dR)
Eco24NP<-lmer(yi_NP~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+(1|reference), weights=Wi_NP, dLi)
Eco25NP<-lmer(yi_NP~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+(1|reference), weights=Wi_NP, dS)
############ model 3 ################
Eco31NP<-lmer(yi_NP~scale(log(N))+scale(ED)+Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_NP, dL)
Eco32NP<-lmer(yi_NP~scale(log(N))+scale(ED)+Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_NP, dST)
Eco33NP<-lmer(yi_NP~scale(log(N))+scale(ED)+Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_NP, dR)
Eco34NP<-lmer(yi_NP~scale(log(N))+scale(ED)+Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_NP, dLi)
Eco35NP<-lmer(yi_NP~scale(log(N))+scale(ED)+Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_NP, dS)
############ model 4 ################
Eco41NP<-lmer(yi_NP~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_NP, dL)
Eco42NP<-lmer(yi_NP~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_NP, dST)
Eco43NP<-lmer(yi_NP~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_NP, dR)
Eco44NP<-lmer(yi_NP~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_NP, dLi)
Eco45NP<-lmer(yi_NP~scale(log(N))+scale(ED)+Ecosystem+scale(log(N))*Ecosystem+scale(ED)*Ecosystem+(1|reference), weights=Wi_NP, dS)

EcoANP1<- rbind(AIC(Eco11NP),AIC(Eco12NP),AIC(Eco13NP),AIC(Eco14NP),AIC(Eco15NP))
EcoBNP1<- rbind(AIC(Eco21NP),AIC(Eco22NP),AIC(Eco23NP),AIC(Eco24NP),AIC(Eco25NP))
EcoCNP1<- rbind(AIC(Eco31NP),AIC(Eco32NP),AIC(Eco33NP),AIC(Eco34NP),AIC(Eco35NP))
EcoDNP1<- rbind(AIC(Eco41NP),AIC(Eco42NP),AIC(Eco43NP),AIC(Eco44NP),AIC(Eco45NP))

EcoNP<-data.frame(cbind(EcoANP1,EcoBNP1,EcoCNP1,EcoDNP1))
write.csv(EcoNP,"EcoNP.csv")

############## MAT ###########
############## log (N) + ED #############
############# model 1 ###########

MAT11NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAT)+(1|reference), weights=Wi_NP, dL)
MAT12NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAT)+(1|reference), weights=Wi_NP, dST)
MAT13NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAT)+(1|reference), weights=Wi_NP, dR)
MAT14NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAT)+(1|reference), weights=Wi_NP, dLi)
MAT15NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAT)+(1|reference), weights=Wi_NP, dS)

############# model 2 ###########
MAT21NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAT)+scale(log(N))*scale(MAT)+(1|reference), weights=Wi_NP, dL)
MAT22NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAT)+scale(log(N))*scale(MAT)+(1|reference), weights=Wi_NP, dST)
MAT23NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAT)+scale(log(N))*scale(MAT)+(1|reference), weights=Wi_NP, dR)
MAT24NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAT)+scale(log(N))*scale(MAT)+(1|reference), weights=Wi_NP, dLi)
MAT25NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAT)+scale(log(N))*scale(MAT)+(1|reference), weights=Wi_NP, dS)

############# model 3 ###########

MAT31NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAT)+scale(log(ED))*scale(MAT)+(1|reference), weights=Wi_NP, dL)
MAT32NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAT)+scale(log(ED))*scale(MAT)+(1|reference), weights=Wi_NP, dST)
MAT33NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAT)+scale(log(ED))*scale(MAT)+(1|reference), weights=Wi_NP, dR)
MAT34NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAT)+scale(log(ED))*scale(MAT)+(1|reference), weights=Wi_NP, dLi)
MAT35NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAT)+scale(log(ED))*scale(MAT)+(1|reference), weights=Wi_NP, dS)

############# model 4 ###########

MAT41NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAT)+(1|reference)+scale(log(ED))*scale(MAT)+scale(log(N))*scale(MAT), weights=Wi_NP, dL)
MAT42NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAT)+(1|reference)+scale(log(ED))*scale(MAT)+scale(log(N))*scale(MAT), weights=Wi_NP, dST)
MAT43NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAT)+(1|reference)+scale(log(ED))*scale(MAT)+scale(log(N))*scale(MAT), weights=Wi_NP, dR)
MAT44NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAT)+(1|reference)+scale(log(ED))*scale(MAT)+scale(log(N))*scale(MAT), weights=Wi_NP, dLi)
MAT45NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAT)+(1|reference)+scale(log(ED))*scale(MAT)+scale(log(N))*scale(MAT), weights=Wi_NP, dS)

MATANP1<- rbind(AIC(MAT11NP),AIC(MAT12NP),AIC(MAT13NP),AIC(MAT14NP),AIC(MAT15NP))
MATBNP1<- rbind(AIC(MAT21NP),AIC(MAT22NP),AIC(MAT23NP),AIC(MAT24NP),AIC(MAT25NP))
MATCNP1<- rbind(AIC(MAT31NP),AIC(MAT32NP),AIC(MAT33NP),AIC(MAT34NP),AIC(MAT35NP))
MATDNP1<- rbind(AIC(MAT41NP),AIC(MAT42NP),AIC(MAT43NP),AIC(MAT44NP),AIC(MAT45NP))

MATNP<-data.frame(cbind(MATANP1,MATBNP1,MATCNP1,MATDNP1))
write.csv(MATNP,"MATNP.csv")


############## MAP ###########
############## log (N) + ED #############
############# model 1 ###########

MAP11NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAP)+(1|reference), weights=Wi_NP, dL)
MAP12NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAP)+(1|reference), weights=Wi_NP, dST)
MAP13NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAP)+(1|reference), weights=Wi_NP, dR)
MAP14NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAP)+(1|reference), weights=Wi_NP, dLi)
MAP15NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAP)+(1|reference), weights=Wi_NP, dS)

############# model 2 ###########
MAP21NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAP)+scale(log(N))*scale(MAP)+(1|reference), weights=Wi_NP, dL)
MAP22NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAP)+scale(log(N))*scale(MAP)+(1|reference), weights=Wi_NP, dST)
MAP23NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAP)+scale(log(N))*scale(MAP)+(1|reference), weights=Wi_NP, dR)
MAP24NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAP)+scale(log(N))*scale(MAP)+(1|reference), weights=Wi_NP, dLi)
MAP25NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAP)+scale(log(N))*scale(MAP)+(1|reference), weights=Wi_NP, dS)

############# model 3 ###########

MAP31NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAP)+scale(log(ED))*scale(MAP)+(1|reference), weights=Wi_NP, dL)
MAP32NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAP)+scale(log(ED))*scale(MAP)+(1|reference), weights=Wi_NP, dST)
MAP33NP<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAP)+scale(log(ED))*scale(MAP)+(1|reference), weights=Wi_NP, dR)
MAP34NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAP)+scale(log(ED))*scale(MAP)+(1|reference), weights=Wi_NP, dLi)
MAP35NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAP)+scale(log(ED))*scale(MAP)+(1|reference), weights=Wi_NP, dS)

############# model 4 ###########

MAP41NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAP)+(1|reference)+scale(log(ED))*scale(MAP)+scale(log(N))*scale(MAP), weights=Wi_NP, dL)
MAP42NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAP)+(1|reference)+scale(log(ED))*scale(MAP)+scale(log(N))*scale(MAP), weights=Wi_NP, dST)
MAP43NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAP)+(1|reference)+scale(log(ED))*scale(MAP)+scale(log(N))*scale(MAP), weights=Wi_NP, dR)
MAP44NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAP)+(1|reference)+scale(log(ED))*scale(MAP)+scale(log(N))*scale(MAP), weights=Wi_NP, dLi)
MAP45NP<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAP)+(1|reference)+scale(log(ED))*scale(MAP)+scale(log(N))*scale(MAP), weights=Wi_NP, dS)

MAPANP1<- rbind(AIC(MAP11NP),AIC(MAP12NP),AIC(MAP13NP),AIC(MAP14NP),AIC(MAP15NP))
MAPBNP1<- rbind(AIC(MAP21NP),AIC(MAP22NP),AIC(MAP23NP),AIC(MAP24NP),AIC(MAP25NP))
MAPCNP1<- rbind(AIC(MAP31NP),AIC(MAP32NP),AIC(MAP33NP),AIC(MAP34NP),AIC(MAP35NP))
MAPDNP1<- rbind(AIC(MAP41NP),AIC(MAP42NP),AIC(MAP43NP),AIC(MAP44NP),AIC(MAP45NP))

MAPNP<-data.frame(cbind(MAPANP1,MAPBNP1,MAPCNP1,MAPDNP1))
write.csv(MAPNP,"MAPNP.csv")
############# we did not use interactive effects of GF ##########



################ N #######################
################ leaf ######################
hmmN_L<-lmer(yi_N~scale(log(N))+ ED+(1|reference), weights = Wi_N, dL)
summary(hmmN_L) ##The beta0 (intercept) is to be reported in Fig. 3 
hist(resid(hmmN_L), breaks=50)
qqnorm(resid(hmmN_L)); qqline(resid(hmmN_L)) 
shapiro.test(resid(hmmN_L)) ##validated normality, bootstraping needed for coefficient estimates   

confint(hmmN_L, method="Wald")##CI from Wald estimate---(intercept) is to be reported in Fig. 3
#confint(hmmN_L, method="boot")

dL$N_L_N<-resid(hmmN_L)+fixef(hmmN_L)[1]+fixef(hmmN_L)[2]*scale(dL$N) 
dL$N_L_ED<-resid(hmmN_L)+fixef(hmmN_L)[1]+fixef(hmmN_L)[3]*scale(dL$ED) 
plot(N_L_N~N, dL)
plot(N_L_ED~ED, dL)

################ Stem ######################
hmmN_ST<-lmer(yi_N~scale(log(N))+scale(ED)+(1|reference), weights = Wi_N, dST)
summary(hmmN_ST) ##The beta0 (intercept) is to be reported in Fig. 3 
hist(resid(hmmN_ST), breaks=50)
qqnorm(resid(hmmN_ST)); qqline(resid(hmmN_ST)) 
shapiro.test(resid(hmmN_ST)) ##validated normality, bootstraping needed for coefficient estimates   


confint(hmmN_ST, method="Wald")##CI from Wald estimate---(intercept) is to be reported in Fig. 3
#confint(hmmN_ST, method="boot")

dST$N_ST_N<-resid(hmmN_ST)+fixef(hmmN_ST)[1]+fixef(hmmN_ST)[2]*scale(dST$N) 
dST$N_ST_ED<-resid(hmmN_ST)+fixef(hmmN_ST)[1]+fixef(hmmN_ST)[3]*scale(dST$ED) 
plot(N_ST_N~N, dST)
plot(N_ST_ED~ED, dST)

################ Root ######################
hmmN_R<-lmer(yi_N~scale(log(N))+scale(ED)+(1|reference), weights = Wi_N, dR)
summary(hmmN_R) ##The beta0 (intercept) is to be reported in Fig. 3 
hist(resid(hmmN_R), breaks=50)
qqnorm(resid(hmmN_R)); qqline(resid(hmmN_R)) 
shapiro.test(resid(hmmN_R)) ##validated normality, bootstraping needed for coefficient estimates   


confint(hmmN_R, method="Wald")##CI from Wald estimate---(intercept) is to be reported in Fig. 3
#confint(hmmN_R, method="boot")

dR$N_R_N<-resid(hmmN_R)+fixef(hmmN_R)[1]+fixef(hmmN_R)[2]*scale(dR$N) 
dR$N_R_ED<-resid(hmmN_R)+fixef(hmmN_R)[1]+fixef(hmmN_R)[3]*scale(dR$ED) 
plot(N_R_N~N, dR)
plot(N_R_ED~ED, dR)

################ Litter ######################
hmmN_Li<-lmer(yi_N~scale(log(N))+scale(ED)+(1|reference), weights = Wi_N, dLi)
summary(hmmN_Li) ##The beta0 (intercept) is to be reported in Fig. 3 
hist(resid(hmmN_Li), breaks=50)
qqnorm(resid(hmmN_Li)); qqline(resid(hmmN_Li)) 
shapiro.test(resid(hmmN_Li)) ##validated normality, bootstraping needed for coefficient estimates   


confint(hmmN_Li, method="Wald")##CI from Wald estimate---(intercept) is to be reported in Fig. 3
#confint(hmmN_Li, method="boot")

dLi$N_Li_N<-resid(hmmN_Li)+fixef(hmmN_Li)[1]+fixef(hmmN_Li)[2]*scale(dLi$N) 
dLi$N_Li_ED<-resid(hmmN_Li)+fixef(hmmN_Li)[1]+fixef(hmmN_Li)[3]*scale(dLi$ED) 
plot(N_Li_N~N, dLi)
plot(N_Li_ED~ED, dLi)

################ Soil ######################
hmmN_S<-lmer(yi_N~scale(log(N))+scale(ED)+(1|reference), weights = Wi_N, dS)
summary(hmmN_S) ##The beta0 (intercept) is to be reported in Fig. 3 
hist(resid(hmmN_S), breaks=50)
qqnorm(resid(hmmN_S)); qqline(resid(hmmN_S)) 
shapiro.test(resid(hmmN_S)) ##validated normality, bootstraping needed for coefficient estimates   


confint(hmmN_S, method="Wald")##CI from Wald estimate---(intercept) is to be reported in Fig. 3
#confint(hmmN_S, method="boot")

dS$N_S_N<-resid(hmmN_S)+fixef(hmmN_S)[1]+fixef(hmmN_S)[2]*scale(dS$N) 
dS$N_S_ED<-resid(hmmN_S)+fixef(hmmN_S)[1]+fixef(hmmN_S)[3]*scale(dS$ED) 
plot(N_S_N~N, dS)
plot(N_S_ED~ED, dS)



################ P #######################
################ leaf ######################
hmmP_L<-lmer(yi_P~scale(log(N))+ ED+(1|reference), weights = Wi_P, dL)
summary(hmmP_L) ##The beta0 (intercept) is to be reported in Fig. 3 
hist(resid(hmmP_L), breaks=50)
qqnorm(resid(hmmP_L)); qqline(resid(hmmP_L)) 
shapiro.test(resid(hmmP_L)) ##validated normality, bootstraping needed for coefficient estimates   


confint(hmmP_L, method="Wald")##CI from Wald estimate---(intercept) is to be reported in Fig. 3
#confint(hmmP_L, method="boot")

dL$P_L_N<-resid(hmmP_L)+fixef(hmmP_L)[1]+fixef(hmmP_L)[2]*scale(dL$N) 
dL$P_L_ED<-resid(hmmP_L)+fixef(hmmP_L)[1]+fixef(hmmP_L)[3]*scale(dL$ED) 
plot(P_L_N~N, dL)
plot(P_L_ED~ED, dL)

################ Stem ######################
hmmP_ST<-lmer(yi_P~scale(log(N))+scale(ED)+(1|reference), weights = Wi_P, dST)
summary(hmmP_ST) ##The beta0 (intercept) is to be reported in Fig. 3 
hist(resid(hmmP_ST), breaks=50)
qqnorm(resid(hmmP_ST)); qqline(resid(hmmP_ST)) 
shapiro.test(resid(hmmP_ST)) ##validated normality, bootstraping needed for coefficient estimates   


confint(hmmP_ST, method="Wald")##CI from Wald estimate---(intercept) is to be reported in Fig. 3
#confint(hmmP_ST, method="boot")

dST$P_ST_N<-resid(hmmP_ST)+fixef(hmmP_ST)[1]+fixef(hmmP_ST)[2]*scale(dST$N) 
dST$P_ST_ED<-resid(hmmP_ST)+fixef(hmmP_ST)[1]+fixef(hmmP_ST)[3]*scale(dST$ED) 
plot(P_ST_N~N, dST)
plot(P_ST_ED~ED, dST)

################ Root ######################
hmmP_R<-lmer(yi_P~scale(log(N))+scale(ED)+(1|reference), weights = Wi_P, dR)
summary(hmmP_R) ##The beta0 (intercept) is to be reported in Fig. 3 
hist(resid(hmmP_R), breaks=50)
qqnorm(resid(hmmP_R)); qqline(resid(hmmP_R)) 
shapiro.test(resid(hmmP_R)) ##validated normality, bootstraping needed for coefficient estimates   


confint(hmmP_R, method="Wald")##CI from Wald estimate---(intercept) is to be reported in Fig. 3
#confint(hmmP_R, method="boot")

dR$P_R_N<-resid(hmmP_R)+fixef(hmmP_R)[1]+fixef(hmmP_R)[2]*scale(dR$N) 
dR$P_R_ED<-resid(hmmP_R)+fixef(hmmP_R)[1]+fixef(hmmP_R)[3]*scale(dR$ED) 
plot(P_R_N~N, dR)
plot(P_R_ED~ED, dR)

################ Litter ######################
hmmP_Li<-lmer(yi_P~scale(log(N))+scale(ED)+(1|reference), weights = Wi_P, dLi)
summary(hmmP_Li) ##The beta0 (intercept) is to be reported in Fig. 3 
hist(resid(hmmP_Li), breaks=50)
qqnorm(resid(hmmP_Li)); qqline(resid(hmmP_Li)) 
shapiro.test(resid(hmmP_Li)) ##validated normality, bootstraping needed for coefficient estimates   


confint(hmmP_Li, method="Wald")##CI from Wald estimate---(intercept) is to be reported in Fig. 3
#confint(hmmP_Li, method="boot")

dLi$P_Li_N<-resid(hmmP_Li)+fixef(hmmP_Li)[1]+fixef(hmmP_Li)[2]*scale(dLi$N) 
dLi$P_Li_ED<-resid(hmmP_Li)+fixef(hmmP_Li)[1]+fixef(hmmP_Li)[3]*scale(dLi$ED) 
plot(P_Li_N~N, dLi)
plot(P_Li_ED~ED, dLi)

################ Soil ######################
hmmP_S<-lmer(yi_P~scale(log(N))+scale(ED)+(1|reference), weights = Wi_P, dS)
summary(hmmP_S) ##The beta0 (intercept) is to be reported in Fig. 3 
hist(resid(hmmP_S), breaks=50)
qqnorm(resid(hmmP_S)); qqline(resid(hmmP_S)) 
shapiro.test(resid(hmmP_S)) ##validated normality, bootstraping needed for coefficient estimates   


confint(hmmN_S, method="Wald")##CI from Wald estimate---(intercept) is to be reported in Fig. 3
#confint(hmmN_S, method="boot")

dS$P_S_N<-resid(hmmP_S)+fixef(hmmP_S)[1]+fixef(hmmP_S)[2]*scale(dS$N) 
dS$P_S_ED<-resid(hmmP_S)+fixef(hmmP_S)[1]+fixef(hmmP_S)[3]*scale(dS$ED) 
plot(P_S_N~N, dS)
plot(P_S_ED~ED, dS)


################ NP #######################
################ leaf ######################
hmmNP_L<-lmer(yi_NP~scale(log(N))+ ED+(1|reference), weights = Wi_NP, dL)
summary(hmmNP_L) ##The beta0 (intercept) is to be reported in Fig. 3 
hist(resid(hmmNP_L), breaks=50)
qqnorm(resid(hmmNP_L)); qqline(resid(hmmNP_L)) 
shapiro.test(resid(hmmNP_L)) ##validated normality, bootstraping needed for coefficient estimates   


confint(hmmNP_L, method="Wald")##CI from Wald estimate---(intercept) is to be reported in Fig. 3
#confint(hmmNP_L, method="boot")

dL$NP_L_N<-resid(hmmNP_L)+fixef(hmmNP_L)[1]+fixef(hmmNP_L)[2]*scale(dL$N) 
dL$NP_L_ED<-resid(hmmNP_L)+fixef(hmmNP_L)[1]+fixef(hmmNP_L)[3]*scale(dL$ED) 
plot(NP_L_N~N, dL)
plot(NP_L_ED~ED, dL)

################ Stem ######################
hmmNP_ST<-lmer(yi_NP~scale(log(N))+scale(ED)+(1|reference), weights = Wi_NP, dST)
summary(hmmNP_ST) ##The beta0 (intercept) is to be reported in Fig. 3 
hist(resid(hmmNP_ST), breaks=50)
qqnorm(resid(hmmNP_ST)); qqline(resid(hmmNP_ST)) 
shapiro.test(resid(hmmNP_ST)) ##validated normality, bootstraping needed for coefficient estimates   


confint(hmmNP_ST, method="Wald")##CI from Wald estimate---(intercept) is to be reported in Fig. 3
#confint(hmmNP_ST, method="boot")

dST$NP_ST_N<-resid(hmmNP_ST)+fixef(hmmNP_ST)[1]+fixef(hmmNP_ST)[2]*scale(dST$N) 
dST$NP_ST_ED<-resid(hmmNP_ST)+fixef(hmmNP_ST)[1]+fixef(hmmNP_ST)[3]*scale(dST$ED) 
plot(NP_ST_N~N, dST)
plot(NP_ST_ED~ED, dST)

################ Root ######################
hmmNP_R<-lmer(yi_NP~scale(log(N))+scale(ED)+(1|reference), weights = Wi_NP, dR)
summary(hmmNP_R) ##The beta0 (intercept) is to be reported in Fig. 3 
hist(resid(hmmNP_R), breaks=50)
qqnorm(resid(hmmNP_R)); qqline(resid(hmmNP_R)) 
shapiro.test(resid(hmmNP_R)) ##validated normality, bootstraping needed for coefficient estimates   


confint(hmmNP_R, method="Wald")##CI from Wald estimate---(intercept) is to be reported in Fig. 3
#confint(hmmNP_R, method="boot")

dR$NP_R_N<-resid(hmmNP_R)+fixef(hmmNP_R)[1]+fixef(hmmNP_R)[2]*scale(dR$N) 
dR$NP_R_ED<-resid(hmmNP_R)+fixef(hmmNP_R)[1]+fixef(hmmNP_R)[3]*scale(dR$ED) 
plot(NP_R_N~N, dR)
plot(NP_R_ED~ED, dR)

################ Litter ######################
hmmNP_Li<-lmer(yi_NP~scale(log(N))+scale(ED)+(1|reference), weights = Wi_NP, dLi)
summary(hmmNP_Li) ##The beta0 (intercept) is to be reported in Fig. 3 
hist(resid(hmmNP_Li), breaks=50)
qqnorm(resid(hmmNP_Li)); qqline(resid(hmmNP_Li)) 
shapiro.test(resid(hmmNP_Li)) ##validated normality, bootstraping needed for coefficient estimates   


confint(hmmNP_Li, method="Wald")##CI from Wald estimate---(intercept) is to be reported in Fig. 3
#confint(hmmNP_Li, method="boot")

dLi$NP_Li_N<-resid(hmmNP_Li)+fixef(hmmNP_Li)[1]+fixef(hmmNP_Li)[2]*scale(dLi$N) 
dLi$NP_Li_ED<-resid(hmmNP_Li)+fixef(hmmNP_Li)[1]+fixef(hmmNP_Li)[3]*scale(dLi$ED) 
plot(NP_Li_N~N, dLi)
plot(NP_Li_ED~ED, dLi)

################ Soil ######################
hmmNP_S<-lmer(yi_NP~scale(log(N))+scale(ED)+(1|reference), weights = Wi_NP, dS)
summary(hmmNP_S) ##The beta0 (intercept) is to be reported in Fig. 3 
hist(resid(hmmNP_S), breaks=50)
qqnorm(resid(hmmNP_S)); qqline(resid(hmmNP_S)) 
shapiro.test(resid(hmmNP_S)) ##validated normality, bootstraping needed for coefficient estimates   


confint(hmmNP_S, method="Wald")##CI from Wald estimate---(intercept) is to be reported in Fig. 3
#confint(hmmNP_S, method="boot")

dS$NP_S_N<-resid(hmmNP_S)+fixef(hmmNP_S)[1]+fixef(hmmNP_S)[2]*scale(dS$N) 
dS$NP_S_ED<-resid(hmmNP_S)+fixef(hmmNP_S)[1]+fixef(hmmNP_S)[3]*scale(dS$ED) 
plot(NP_S_N~N, dS)
plot(NP_S_ED~ED, dS)


################# main effects ###############
################# Fig. 2a #################
############### N #####################
## function t() to transpose data
dF1 <-rbind(data.frame(t(confint(hmmN_L, method="Wald")[3,]), EC = "Leaf"),
            data.frame(t(confint(hmmN_ST, method="Wald")[3,]), EC = "Stem"),
            data.frame(t(confint(hmmN_R, method="Wald")[3,]), EC = "Root"),
            data.frame(t(confint(hmmN_Li, method="Wald")[3,]), EC = "Litter"),
            data.frame(t(confint(hmmN_S, method="Wald")[3,]), EC = "Soil"))
dF1$mean<-(dF1$X2.5..+dF1$X97.5..)/2
dF1 <- setNames(dF1, c("cl","cu", "EC", "mean"))

DT<-data.table(d1)
N_C<-DT[, .N, by=EC]
N_S<-DT[, .(NS= length(unique(reference))), by = EC]
NCS<-merge(N_C, N_S)


dF1 <- merge(dF1, NCS)
dF1$st <-paste(dF1$N,"(", dF1$NS, ")")
### percentage conversion for text

dF1$cl_p<-(exp(dF1$cl)-1)*100
dF1$cu_p<-(exp(dF1$cu)-1)*100
dF1$mean_p<-(dF1$cl_p+dF1$cu_p)/2
dF1
dF1$EC <- factor(dF1$EC, levels = c("Leaf",
                                    "Litter",    
                                    "Root",     
                                    "Soil",   
                                    "Stem"),
                 labels = c("Leaf",
                            "Litter",    
                            "Root",     
                            "Soil",   
                            "Stem"))

# set a color palette
MyColour <- c("#0073C2FF", "#EFC000FF") ## blue errorbar shows "NON-significance"

ggplot(dF1) + geom_point(aes(x=EC, y=mean_p, color = (cu_p < 0 | cl_p > 0)), shape = 15, size = 3.5)+
    geom_errorbar(aes(x=EC,ymin=cl_p, ymax=cu_p, color = (cu_p < 0 | cl_p > 0)), width = 0, size = 1)+
    scale_color_manual(values = MyColour) +
    geom_text(aes(label=st,x=EC, y=50,hjust=0), size=3)+
    coord_flip(ylim = c(-60, 80))+ scale_x_discrete(limits = rev(levels(dF1$EC)))+
    geom_hline(aes(yintercept=0),linetype="dashed",colour="black")+
    xlab("")+ylab("Effect size (%)") +
    theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                      panel.grid.minor = element_blank(),
                      panel.background = element_blank())+
    theme(strip.background = element_blank(), strip.placement = "outside")+
    theme(legend.position="none")

################# Fig. 2b #################
############### P #####################
## function t() to transpose data
dF2 <-rbind(data.frame(t(confint(hmmP_L, method="Wald")[3,]), EC = "Leaf"),
            data.frame(t(confint(hmmP_ST, method="Wald")[3,]), EC = "Stem"),
            data.frame(t(confint(hmmP_R, method="Wald")[3,]), EC = "Root"),
            data.frame(t(confint(hmmP_Li, method="Wald")[3,]), EC = "Litter"),
            data.frame(t(confint(hmmP_S, method="Wald")[3,]), EC = "Soil"))
dF2$mean<-(dF2$X2.5..+dF2$X97.5..)/2
dF2 <- setNames(dF2, c("cl","cu", "EC", "mean"))

DT<-data.table(d1)
N_C<-DT[, .N, by=EC]
N_S<-DT[, .(NS= length(unique(reference))), by = EC]
NCS<-merge(N_C, N_S)

dF2 <- merge(dF2, NCS)
dF2$st <-paste(dF2$N,"(", dF2$NS, ")")
### percentage conversion for text

dF2$cl_p<-(exp(dF2$cl)-1)*100
dF2$cu_p<-(exp(dF2$cu)-1)*100
dF2$mean_p<-(dF2$cl_p+dF2$cu_p)/2
dF2
dF2$EC <- factor(dF2$EC, levels = c("Leaf",
                                    "Litter",    
                                    "Root",     
                                    "Soil",   
                                    "Stem"),
                 labels = c("Leaf",
                            "Litter",    
                            "Root",     
                            "Soil",   
                            "Stem"))

# set a color palette
MyColour <- c("#0073C2FF", "#EFC000FF") ## blue errorbar shows "NON-significance"

ggplot(dF2) + geom_point(aes(x=EC, y=mean_p, color = (cu_p < 0 | cl_p > 0)), shape = 15, size = 3.5)+
  geom_errorbar(aes(x=EC,ymin=cl_p, ymax=cu_p, color = (cu_p < 0 | cl_p > 0)), width = 0, size = 1)+
  scale_color_manual(values = MyColour) +
  geom_text(aes(label=st,x=EC, y=50,hjust=0), size=3)+
  coord_flip(ylim = c(-60, 80))+ scale_x_discrete(limits = rev(levels(dF1$EC)))+
  geom_hline(aes(yintercept=0),linetype="dashed",colour="black")+
  xlab("")+ylab("Effect size (%)") +
  theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                    panel.grid.minor = element_blank(),
                    panel.background = element_blank())+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  theme(legend.position="none")


################# Fig. 2c #################
############### NP #####################
## function t() to transpose data
dF3 <-rbind(data.frame(t(confint(hmmNP_L, method="Wald")[3,]), EC = "Leaf"),
            data.frame(t(confint(hmmNP_ST, method="Wald")[3,]), EC = "Stem"),
            data.frame(t(confint(hmmNP_R, method="Wald")[3,]), EC = "Root"),
            data.frame(t(confint(hmmNP_Li, method="Wald")[3,]), EC = "Litter"),
            data.frame(t(confint(hmmNP_S, method="Wald")[3,]), EC = "Soil"))
dF3$mean<-(dF3$X2.5..+dF3$X97.5..)/2
dF3 <- setNames(dF3, c("cl","cu", "EC", "mean"))

DT<-data.table(d1)
N_C<-DT[, .N, by=EC]
N_S<-DT[, .(NS= length(unique(reference))), by = EC]
NCS<-merge(N_C, N_S)

dF3 <- merge(dF3, NCS)
dF3$st <-paste(dF3$N,"(", dF3$NS, ")")
### percentage conversion for text

dF3$cl_p<-(exp(dF3$cl)-1)*100
dF3$cu_p<-(exp(dF3$cu)-1)*100
dF3$mean_p<-(dF3$cl_p+dF3$cu_p)/2
dF3
dF3$EC <- factor(dF3$EC, levels = c("Leaf",
                                    "Litter",    
                                    "Root",     
                                    "Soil",   
                                    "Stem"),
                 labels = c("Leaf",
                            "Litter",    
                            "Root",     
                            "Soil",   
                            "Stem"))

# set a color palette
MyColour <- c("#0073C2FF", "#EFC000FF") ## blue errorbar shows "NON-significance"

ggplot(dF3) + geom_point(aes(x=EC, y=mean_p, color = (cu_p < 0 | cl_p > 0)), shape = 15, size = 3.5)+
  geom_errorbar(aes(x=EC,ymin=cl_p, ymax=cu_p, color = (cu_p < 0 | cl_p > 0)), width = 0, size = 1)+
  scale_color_manual(values = MyColour) +
  geom_text(aes(label=st,x=EC, y=50,hjust=0), size=3)+
  coord_flip(ylim = c(-60, 80))+ scale_x_discrete(limits = rev(levels(dF1$EC)))+
  geom_hline(aes(yintercept=0),linetype="dashed",colour="black")+
  xlab("")+ylab("Effect size (%)") +
  theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                    panel.grid.minor = element_blank(),
                    panel.background = element_blank())+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  theme(legend.position="none")

###### Full Fig.2 #######
#### combind Fig 2a 2b 2c
## data for ggplot2 "facet" ploting
dF.Fig2 <- rbind(data.frame(dF1, type = "Response of [N]"),
                 data.frame(dF2, type = "Response of [P]"),
                 data.frame(dF3, type = "Response of N:P"))

ggplot(dF.Fig2) + 
    geom_tile(aes(x = EC, y = rep(1:5, 3), fill = as.factor(rep(1:5, 3))), height = Inf, show.legend = F) +
    scale_fill_manual(values = c(rep("white", 3), rep("grey95", 2), "white", "grey95")) +
    geom_point(aes(x=EC, y=mean_p, color = (cu_p < 0 | cl_p > 0)),stat="identity", shape=15,size=3.5)+
    geom_errorbar(aes(x=EC,ymin=cl_p, ymax=cu_p, color = (cu_p < 0 | cl_p > 0)), width=0, size = 1)+
    geom_text(aes(label=st,x=EC, y=50,hjust=0), size=3)+
    scale_colour_manual(values = c("#0073C2FF", "#EFC000FF")) +
    guides(color = guide_legend(title = "Significance")) +
    coord_flip(ylim = c(-40, 80))+ scale_x_discrete(limits = rev(levels(dF2$EC)))+
    geom_hline(aes(yintercept = 0), linetype = 2, colour = "black", alpha = 0.5)+
    xlab("")+ ylab("Effect size (%)") +
    facet_grid(. ~ type) +
    theme_light() +
    theme(strip.text = element_text(face = "bold"),
          legend.position = "none")

######### Figs 3 & 4 #####
########### N & ED effects #########
## C + N + C:N vs. N plots
all.Fig4 <- rbind(melt(dL[ , c(9:11, 18:23)], id = 1:3), 
                  melt(dST[ , c(9:11, 18:23)], id = 1:3),
                  melt(dR[ , c(9:11, 18:23)], id = 1:3), 
                  melt(dLi[ , c(9:11, 18:23)], id = 1:3),
                  melt(dS[ , c(9:11, 18:23)], id = 1:3)) 

View(all.Fig4)

## ssplit col "variable" to 3 cols "element", "EC_not_use", "X_type")
split.all.Fig4 <- all.Fig4 %>% separate(variable, c("element", "EC_not_use", "X_type"))
## order of legends
split.all.Fig4$EC <- factor(split.all.Fig4$EC, levels = c("Leaf",
                                                          "Stem",
                                                          "Root",
                                                          "Litter",
                                                          "Soil"),
                            labels = c("Leaf",
                                       "Stem",
                                       "Root",
                                       "Litter",
                                       "Soil"))
## order of facets
split.all.Fig4$element <- factor(split.all.Fig4$element,
                                 levels = c("N", "P", "NP"),
                                 labels = c("Response of N", "Response of P", "Response of N:P"))

## plot EC x N
ggplot(data = split.all.Fig4, aes(x = N, y = value, color = element)) +
  geom_point(shape = 1, size = 2, alpha = 0.2) +
  stat_smooth(method = lm, size = 0.8) +
  scale_color_brewer(palette = "Set1") +
  guides(color = guide_legend(title = NULL)) +
  ylab("Log response ratio") + 
  xlab(expression(
    paste("ln (N input rate (g m"^-2,"yr"^-1,")) ")))+
  coord_cartesian(ylim=c(-2,2))+
  geom_hline(aes(yintercept = 0),linetype="dashed",colour="black") +
  facet_wrap(EC ~ ., nrow = 2, scales = "free_x") + ##  norw = 2 
  geom_text(data = data.frame(lab = c("a", "b", "c", "d", "e"),
                              EC = unique(split.all.Fig4$EC)),
            aes(x = -Inf, y = 2, label = lab), hjust = -1.2, 
            size=3,fontface="bold",inherit.aes = FALSE) + 
  theme_bw() 


## plot EC x ED
ggplot(data = split.all.Fig4, aes(x = ED, y = value, color = element)) +
  geom_point(shape = 1, size = 2, alpha = 0.2) +
  stat_smooth(method = lm, size = 0.8) +
  scale_color_brewer(palette = "Set1") +
  guides(color = guide_legend(title = NULL)) +
  labs(x = "Experimental duration (days)", y = "Log response ratio") +
  coord_cartesian(ylim=c(-2,2))+
  geom_hline(aes(yintercept = 0),linetype="dashed",colour="black") +
  facet_wrap(EC ~ ., nrow = 2, scales = "free_x") +
  geom_text(data = data.frame(lab = c("a", "b", "c", "d", "e"),
                              EC = unique(split.all.Fig4$EC)),
            aes(x = -Inf, y = 2, hjust = -1.5, label = lab), 
            size=3,fontface="bold",inherit.aes = FALSE) +
  theme_bw() 

############## geographical factors ###############
############### Fig  ############
########## Ecosystem x EC ############
############## N ##############
########## leaf #############
hmmNL_FG<-lmer(yi_N~scale(log(N))+scale(log (ED))+Ecosystem-1 + (1|reference), weights = Wi_N,dL)
summary(hmmNL_FG)
confint(hmmNL_FG, method = "Wald")
########## stem #############
hmmNST_FG<-lmer(yi_N~scale(log(N))+scale(log (ED))+Ecosystem-1 + (1|reference), weights = Wi_N,dST)
summary(hmmNST_FG)
confint(hmmNST_FG, method = "Wald")
########## root #############
hmmNR_FG<-lmer(yi_N~scale(log(N))+scale(log (ED))+Ecosystem-1 + (1|reference), weights = Wi_N,dR)
summary(hmmNR_FG)
confint(hmmNR_FG, method = "Wald")
########## litter #############
hmmNLi_FG<-lmer(yi_N~scale(log(N))+scale(log (ED))+Ecosystem-1 + (1|reference), weights = Wi_N,dLi)
summary(hmmNLi_FG)
confint(hmmNLi_FG, method = "Wald")
########## Soil #############
hmmNS_FG<-lmer(yi_N~scale(log(N))+scale(log (ED))+Ecosystem-1 + (1|reference), weights = Wi_N,dS)
summary(hmmNS_FG)
confint(hmmNS_FG, method = "Wald")

############## P ##############
########## leaf #############
hmmPL_FG<-lmer(yi_P~scale(log(N))+scale(log (ED))+Ecosystem-1 + (1|reference), weights = Wi_P,dL)
summary(hmmPL_FG)
confint(hmmPL_FG, method = "Wald")
########## stem #############
hmmPST_FG<-lmer(yi_P~scale(log(N))+scale(log (ED))+Ecosystem-1 + (1|reference), weights = Wi_P,dST)
summary(hmmPST_FG)
confint(hmmPST_FG, method = "Wald")
########## root #############
hmmPR_FG<-lmer(yi_P~scale(log(N))+scale(log (ED))+Ecosystem-1 + (1|reference), weights = Wi_P,dR)
summary(hmmPR_FG)
confint(hmmPR_FG, method = "Wald")
########## litter #############
hmmPLi_FG<-lmer(yi_P~scale(log(N))+scale(log (ED))+Ecosystem-1 + (1|reference), weights = Wi_P,dLi)
summary(hmmPLi_FG)
confint(hmmPLi_FG, method = "Wald")
########## Soil #############
hmmPS_FG<-lmer(yi_P~scale(log(N))+scale(log (ED))+Ecosystem-1 + (1|reference), weights = Wi_P,dS)
summary(hmmPS_FG)
confint(hmmPS_FG, method = "Wald")


############## NP ##############
########## leaf #############
hmmNPL_FG<-lmer(yi_NP~scale(log(N))+scale(log (ED))+Ecosystem-1 + (1|reference), weights = Wi_NP,dL)
summary(hmmNPL_FG)
confint(hmmNPL_FG, method = "Wald")
########## stem #############
hmmNPST_FG<-lmer(yi_NP~scale(log(N))+scale(log (ED))+Ecosystem-1 + (1|reference), weights = Wi_NP,dST)
summary(hmmNPST_FG)
confint(hmmNST_FG, method = "Wald")
########## root #############
hmmNPR_FG<-lmer(yi_NP~scale(log(N))+scale(log (ED))+Ecosystem-1 + (1|reference), weights = Wi_NP,dR)
summary(hmmNPR_FG)
confint(hmmNPR_FG, method = "Wald")
########## litter #############
hmmNPLi_FG<-lmer(yi_NP~scale(log(N))+scale(log (ED))+Ecosystem-1 + (1|reference), weights = Wi_NP,dLi)
summary(hmmNPLi_FG)
confint(hmmNPLi_FG, method = "Wald")
########## Soil #############
hmmNPS_FG<-lmer(yi_NP~scale(log(N))+scale(log (ED))+Ecosystem-1 + (1|reference), weights = Wi_NP,dS)
summary(hmmNPS_FG)
confint(hmmNPS_FG, method = "Wald")

############### Fig 5 ###################
######### Forest #############
############ N #############

dF5 <-rbind(data.frame(t(confint(hmmNL_FG, method="Wald")[5,]), EC = "Leaf"),
            data.frame(t(confint(hmmNST_FG, method="Wald")[5,]), EC = "Stem"),
            data.frame(t(confint(hmmNR_FG, method="Wald")[5,]), EC = "Root"),
            data.frame(t(confint(hmmNLi_FG, method="Wald")[5,]), EC = "Litter"),
            data.frame(t(confint(hmmNS_FG, method="Wald")[5,]), EC = "Soil"))
dF5$mean<-(dF5$X2.5..+dF5$X97.5..)/2
dF5 <- setNames(dF5, c("cl","cu", "EC", "mean"))

DT<-data.table(d1)
N_C<-DT[, .N, by=c("EC", "Ecosystem")]
N_S<-DT[, .(NS= length(unique(reference))), by = c("EC", "Ecosystem")]
NCS<-merge(N_C, N_S)

dF5 <- merge(dF5, NCS)
dF5$st <-paste(dF5$N,"(", dF5$NS, ")")

### percentage conversion for text

dF5$cl_p<-(exp(dF5$cl)-1)*100
dF5$cu_p<-(exp(dF5$cu)-1)*100
dF5$mean_p<-(dF5$cl_p+dF5$cu_p)/2
dF5

dF5$EC <- factor(dF5$EC, levels = c("Leaf",
                                    "Litter",    
                                    "Root",     
                                    "Soil",   
                                    "Stem"),
                 labels = c("Leaf",
                            "Litter",    
                            "Root",     
                            "Soil",   
                            "Stem"))
setDT(dF5)
class(dF5)

ggplot(dF5[Ecosystem == "Forest"])+ geom_point(aes(x=EC, y=mean_p), shape=1,size=3.5)+
  geom_errorbar(aes(x=EC,ymin=cl_p, ymax=cu_p), width=0)+
  geom_text(aes(label=st,x=EC, y=50,hjust=0), size=3)+
  coord_flip(ylim = c(-60, 80))+ scale_x_discrete(limits = rev(levels(dF5$EC)))+
  geom_hline(aes(yintercept=0),linetype="dashed",colour="black")+
  xlab("")+ylab("Effect size (%)") +
  theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                    panel.grid.minor = element_blank(),
                    panel.background = element_blank())+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  theme(legend.position="none")


############ P #############

dF6 <-rbind(data.frame(t(confint(hmmPL_FG, method="Wald")[5,]), EC = "Leaf"),
            data.frame(t(confint(hmmPST_FG, method="Wald")[5,]), EC = "Stem"),
            data.frame(t(confint(hmmPR_FG, method="Wald")[5,]), EC = "Root"),
            data.frame(t(confint(hmmPLi_FG, method="Wald")[5,]), EC = "Litter"),
            data.frame(t(confint(hmmPS_FG, method="Wald")[5,]), EC = "Soil"))
dF6$mean<-(dF6$X2.5..+dF6$X97.5..)/2
dF6 <- setNames(dF6, c("cl","cu", "EC", "mean"))

DT<-data.table(d1)
N_C<-DT[, .N, by=c("EC", "Ecosystem")]
N_S<-DT[, .(NS= length(unique(reference))), by = c("EC", "Ecosystem")]
NCS<-merge(N_C, N_S)

dF6 <- merge(dF6, NCS)
dF6$st <-paste(dF6$N,"(", dF6$NS, ")")

### percentage conversion for text

dF6$cl_p<-(exp(dF6$cl)-1)*100
dF6$cu_p<-(exp(dF6$cu)-1)*100
dF6$mean_p<-(dF6$cl_p+dF6$cu_p)/2
dF6

dF6$EC <- factor(dF6$EC, levels = c("Leaf",
                                    "Litter",    
                                    "Root",     
                                    "Soil",   
                                    "Stem"),
                 labels = c("Leaf",
                            "Litter",    
                            "Root",     
                            "Soil",   
                            "Stem"))
setDT(dF6)
class(dF6)

ggplot(dF6[Ecosystem == "Forest"])+ geom_point(aes(x=EC, y=mean_p), shape=1,size=3.5)+
  geom_errorbar(aes(x=EC,ymin=cl_p, ymax=cu_p), width=0)+
  geom_text(aes(label=st,x=EC, y=50,hjust=0), size=3)+
  coord_flip(ylim = c(-60, 80))+ scale_x_discrete(limits = rev(levels(dF5$EC)))+
  geom_hline(aes(yintercept=0),linetype="dashed",colour="black")+
  xlab("")+ylab("Effect size (%)") +
  theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                    panel.grid.minor = element_blank(),
                    panel.background = element_blank())+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  theme(legend.position="none")


############ NP #############

dF7 <-rbind(data.frame(t(confint(hmmNPL_FG, method="Wald")[5,]), EC = "Leaf"),
            data.frame(t(confint(hmmNPST_FG, method="Wald")[5,]), EC = "Stem"),
            data.frame(t(confint(hmmNPR_FG, method="Wald")[5,]), EC = "Root"),
            data.frame(t(confint(hmmNPLi_FG, method="Wald")[5,]), EC = "Litter"),
            data.frame(t(confint(hmmNPS_FG, method="Wald")[5,]), EC = "Soil"))
dF7$mean<-(dF7$X2.5..+dF7$X97.5..)/2
dF7 <- setNames(dF7, c("cl","cu", "EC", "mean"))

DT<-data.table(d1)
N_C<-DT[, .N, by=c("EC", "Ecosystem")]
N_S<-DT[, .(NS= length(unique(reference))), by = c("EC", "Ecosystem")]
NCS<-merge(N_C, N_S)

dF7 <- merge(dF7, NCS)
dF7$st <-paste(dF7$N,"(", dF7$NS, ")")

### percentage conversion for text

dF7$cl_p<-(exp(dF7$cl)-1)*100
dF7$cu_p<-(exp(dF7$cu)-1)*100
dF7$mean_p<-(dF7$cl_p+dF7$cu_p)/2
dF7

dF7$EC <- factor(dF7$EC, levels = c("Leaf",
                                    "Litter",    
                                    "Root",     
                                    "Soil",   
                                    "Stem"),
                 labels = c("Leaf",
                            "Litter",    
                            "Root",     
                            "Soil",   
                            "Stem"))
setDT(dF7)
class(dF7)

ggplot(dF7[Ecosystem == "Forest"])+ geom_point(aes(x=EC, y=mean_p), shape=1,size=3.5)+
  geom_errorbar(aes(x=EC,ymin=cl_p, ymax=cu_p), width=0)+
  geom_text(aes(label=st,x=EC, y=50,hjust=0), size=3)+
  coord_flip(ylim = c(-60, 80))+ scale_x_discrete(limits = rev(levels(dF5$EC)))+
  geom_hline(aes(yintercept=0),linetype="dashed",colour="black")+
  xlab("")+ylab("Effect size (%)") +
  theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                    panel.grid.minor = element_blank(),
                    panel.background = element_blank())+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  theme(legend.position="none")

######### Grassland #############
############ N #############

dF8 <-rbind(data.frame(t(confint(hmmNL_FG, method="Wald")[6,]), EC = "Leaf"),
            data.frame(t(confint(hmmNST_FG, method="Wald")[6,]), EC = "Stem"),
            data.frame(t(confint(hmmNR_FG, method="Wald")[6,]), EC = "Root"),
            data.frame(t(confint(hmmNLi_FG, method="Wald")[6,]), EC = "Litter"),
            data.frame(t(confint(hmmNS_FG, method="Wald")[6,]), EC = "Soil"))
dF8$mean<-(dF8$X2.5..+dF8$X97.5..)/2
dF8 <- setNames(dF8, c("cl","cu", "EC", "mean"))

DT<-data.table(d1)
N_C<-DT[, .N, by=c("EC", "Ecosystem")]
N_S<-DT[, .(NS= length(unique(reference))), by = c("EC", "Ecosystem")]
NCS<-merge(N_C, N_S)

dF8 <- merge(dF8, NCS)
dF8$st <-paste(dF8$N,"(", dF8$NS, ")")

### percentage conversion for text

dF8$cl_p<-(exp(dF8$cl)-1)*100
dF8$cu_p<-(exp(dF8$cu)-1)*100
dF8$mean_p<-(dF8$cl_p+dF8$cu_p)/2
dF8

dF8$EC <- factor(dF8$EC, levels = c("Leaf",
                                    "Litter",    
                                    "Root",     
                                    "Soil",   
                                    "Stem"),
                 labels = c("Leaf",
                            "Litter",    
                            "Root",     
                            "Soil",   
                            "Stem"))
setDT(dF8)
class(dF8)

ggplot(dF8[Ecosystem == "Grassland"])+ geom_point(aes(x=EC, y=mean_p), shape=1,size=3.5)+
  geom_errorbar(aes(x=EC,ymin=cl_p, ymax=cu_p), width=0)+
  geom_text(aes(label=st,x=EC, y=50,hjust=0), size=3)+
  coord_flip(ylim = c(-60, 80))+ scale_x_discrete(limits = rev(levels(dF5$EC)))+
  geom_hline(aes(yintercept=0),linetype="dashed",colour="black")+
  xlab("")+ylab("Effect size (%)") +
  theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                    panel.grid.minor = element_blank(),
                    panel.background = element_blank())+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  theme(legend.position="none")


############ P #############

dF9 <-rbind(data.frame(t(confint(hmmPL_FG, method="Wald")[6,]), EC = "Leaf"),
            data.frame(t(confint(hmmPST_FG, method="Wald")[6,]), EC = "Stem"),
            data.frame(t(confint(hmmPR_FG, method="Wald")[6,]), EC = "Root"),
            data.frame(t(confint(hmmPLi_FG, method="Wald")[6,]), EC = "Litter"),
            data.frame(t(confint(hmmPS_FG, method="Wald")[6,]), EC = "Soil"))
dF9$mean<-(dF9$X2.5..+dF9$X97.5..)/2
dF9 <- setNames(dF9, c("cl","cu", "EC", "mean"))

DT<-data.table(d1)
N_C<-DT[, .N, by=c("EC", "Ecosystem")]
N_S<-DT[, .(NS= length(unique(reference))), by = c("EC", "Ecosystem")]
NCS<-merge(N_C, N_S)

dF9 <- merge(dF9, NCS)
dF9$st <-paste(dF9$N,"(", dF9$NS, ")")

### percentage conversion for text

dF9$cl_p<-(exp(dF9$cl)-1)*100
dF9$cu_p<-(exp(dF9$cu)-1)*100
dF9$mean_p<-(dF9$cl_p+dF9$cu_p)/2
dF9

dF9$EC <- factor(dF9$EC, levels = c("Leaf",
                                    "Litter",    
                                    "Root",     
                                    "Soil",   
                                    "Stem"),
                 labels = c("Leaf",
                            "Litter",    
                            "Root",     
                            "Soil",   
                            "Stem"))
setDT(dF9)
class(dF9)

ggplot(dF9[Ecosystem == "Grassland"])+ geom_point(aes(x=EC, y=mean_p), shape=1,size=3.5)+
  geom_errorbar(aes(x=EC,ymin=cl_p, ymax=cu_p), width=0)+
  geom_text(aes(label=st,x=EC, y=-40,hjust=0), size=3)+
  coord_flip(ylim = c(-60, 80))+ scale_x_discrete(limits = rev(levels(dF5$EC)))+
  geom_hline(aes(yintercept=0),linetype="dashed",colour="black")+
  xlab("")+ylab("Effect size (%)") +
  theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                    panel.grid.minor = element_blank(),
                    panel.background = element_blank())+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  theme(legend.position="none")


############ NP #############

dF10 <-rbind(data.frame(t(confint(hmmNPL_FG, method="Wald")[6,]), EC = "Leaf"),
            data.frame(t(confint(hmmNPST_FG, method="Wald")[6,]), EC = "Stem"),
            data.frame(t(confint(hmmNPR_FG, method="Wald")[6,]), EC = "Root"),
            data.frame(t(confint(hmmNPLi_FG, method="Wald")[6,]), EC = "Litter"),
            data.frame(t(confint(hmmNPS_FG, method="Wald")[6,]), EC = "Soil"))
dF10$mean<-(dF10$X2.5..+dF10$X97.5..)/2
dF10 <- setNames(dF10, c("cl","cu", "EC", "mean"))

DT<-data.table(d1)
N_C<-DT[, .N, by=c("EC", "Ecosystem")]
N_S<-DT[, .(NS= length(unique(reference))), by = c("EC", "Ecosystem")]
NCS<-merge(N_C, N_S)

dF10 <- merge(dF10, NCS)
dF10$st <-paste(dF10$N,"(", dF10$NS, ")")

### percentage conversion for text

dF10$cl_p<-(exp(dF10$cl)-1)*100
dF10$cu_p<-(exp(dF10$cu)-1)*100
dF10$mean_p<-(dF10$cl_p+dF10$cu_p)/2
dF10

dF10$EC <- factor(dF10$EC, levels = c("Leaf",
                                    "Litter",    
                                    "Root",     
                                    "Soil",   
                                    "Stem"),
                 labels = c("Leaf",
                            "Litter",    
                            "Root",     
                            "Soil",   
                            "Stem"))
setDT(dF10)
class(dF10)

ggplot(dF10[Ecosystem == "Grassland"])+ geom_point(aes(x=EC, y=mean_p), shape=1,size=3.5)+
  geom_errorbar(aes(x=EC,ymin=cl_p, ymax=cu_p), width=0)+
  geom_text(aes(label=st,x=EC, y=50,hjust=0), size=3)+
  coord_flip(ylim = c(-60, 80))+ scale_x_discrete(limits = rev(levels(dF5$EC)))+
  geom_hline(aes(yintercept=0),linetype="dashed",colour="black")+
  xlab("")+ylab("Effect size (%)") +
  theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                    panel.grid.minor = element_blank(),
                    panel.background = element_blank())+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  theme(legend.position="none")

######### Pot #############
############ N #############

dF11 <-rbind(data.frame(t(confint(hmmNL_FG, method="Wald")[7,]), EC = "Leaf"),
            data.frame(t(confint(hmmNST_FG, method="Wald")[7,]), EC = "Stem"),
            data.frame(t(confint(hmmNR_FG, method="Wald")[7,]), EC = "Root"),
            data.frame(t(confint(hmmNLi_FG, method="Wald")[7,]), EC = "Litter"),
            data.frame(t(confint(hmmNS_FG, method="Wald")[7,]), EC = "Soil"))
dF11$mean<-(dF11$X2.5..+dF11$X97.5..)/2
dF11 <- setNames(dF11, c("cl","cu", "EC", "mean"))

DT<-data.table(d1)
N_C<-DT[, .N, by=c("EC", "Ecosystem")]
N_S<-DT[, .(NS= length(unique(reference))), by = c("EC", "Ecosystem")]
NCS<-merge(N_C, N_S)

dF11 <- merge(dF11, NCS)
dF11$st <-paste(dF11$N,"(", dF11$NS, ")")

### percentage conversion for text

dF11$cl_p<-(exp(dF11$cl)-1)*100
dF11$cu_p<-(exp(dF11$cu)-1)*100
dF11$mean_p<-(dF11$cl_p+dF11$cu_p)/2
dF11

dF11$EC <- factor(dF11$EC, levels = c("Leaf",
                                    "Litter",    
                                    "Root",     
                                    "Soil",   
                                    "Stem"),
                 labels = c("Leaf",
                            "Litter",    
                            "Root",     
                            "Soil",   
                            "Stem"))
setDT(dF11)
class(dF11)

ggplot(dF11[Ecosystem == "Pot"])+ geom_point(aes(x=EC, y=mean_p), shape=1,size=3.5)+
  geom_errorbar(aes(x=EC,ymin=cl_p, ymax=cu_p), width=0)+
  geom_text(aes(label=st,x=EC, y=-40,hjust=0), size=3)+
  coord_flip(ylim = c(-60, 80))+ scale_x_discrete(limits = rev(levels(dF5$EC)))+
  geom_hline(aes(yintercept=0),linetype="dashed",colour="black")+
  xlab("")+ylab("Effect size (%)") +
  theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                    panel.grid.minor = element_blank(),
                    panel.background = element_blank())+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  theme(legend.position="none")


############ P #############

dF12 <-rbind(data.frame(t(confint(hmmPL_FG, method="Wald")[7,]), EC = "Leaf"),
            data.frame(t(confint(hmmPST_FG, method="Wald")[7,]), EC = "Stem"),
            data.frame(t(confint(hmmPR_FG, method="Wald")[7,]), EC = "Root"),
            data.frame(t(confint(hmmPLi_FG, method="Wald")[7,]), EC = "Litter"),
            data.frame(t(confint(hmmPS_FG, method="Wald")[7,]), EC = "Soil"))
dF12$mean<-(dF12$X2.5..+dF12$X97.5..)/2
dF12 <- setNames(dF12, c("cl","cu", "EC", "mean"))

DT<-data.table(d1)
N_C<-DT[, .N, by=c("EC", "Ecosystem")]
N_S<-DT[, .(NS= length(unique(reference))), by = c("EC", "Ecosystem")]
NCS<-merge(N_C, N_S)

dF12 <- merge(dF12, NCS)
dF12$st <-paste(dF12$N,"(", dF12$NS, ")")

### percentage conversion for text

dF12$cl_p<-(exp(dF12$cl)-1)*100
dF12$cu_p<-(exp(dF12$cu)-1)*100
dF12$mean_p<-(dF12$cl_p+dF12$cu_p)/2
dF12

dF12$EC <- factor(dF12$EC, levels = c("Leaf",
                                    "Litter",    
                                    "Root",     
                                    "Soil",   
                                    "Stem"),
                 labels = c("Leaf",
                            "Litter",    
                            "Root",     
                            "Soil",   
                            "Stem"))
setDT(dF12)
class(dF12)

ggplot(dF12[Ecosystem == "Pot"])+ geom_point(aes(x=EC, y=mean_p), shape=1,size=3.5)+
  geom_errorbar(aes(x=EC,ymin=cl_p, ymax=cu_p), width=0)+
  geom_text(aes(label=st,x=EC, y=-50,hjust=0), size=3)+
  coord_flip(ylim = c(-60, 80))+ scale_x_discrete(limits = rev(levels(dF5$EC)))+
  geom_hline(aes(yintercept=0),linetype="dashed",colour="black")+
  xlab("")+ylab("Effect size (%)") +
  theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                    panel.grid.minor = element_blank(),
                    panel.background = element_blank())+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  theme(legend.position="none")


############ NP #############

dF13 <-rbind(data.frame(t(confint(hmmNPL_FG, method="Wald")[7,]), EC = "Leaf"),
             data.frame(t(confint(hmmNPST_FG, method="Wald")[7,]), EC = "Stem"),
             data.frame(t(confint(hmmNPR_FG, method="Wald")[7,]), EC = "Root"),
             data.frame(t(confint(hmmNPLi_FG, method="Wald")[7,]), EC = "Litter"),
             data.frame(t(confint(hmmNPS_FG, method="Wald")[7,]), EC = "Soil"))
dF13$mean<-(dF13$X2.5..+dF13$X97.5..)/2
dF13 <- setNames(dF13, c("cl","cu", "EC", "mean"))

DT<-data.table(d1)
N_C<-DT[, .N, by=c("EC", "Ecosystem")]
N_S<-DT[, .(NS= length(unique(reference))), by = c("EC", "Ecosystem")]
NCS<-merge(N_C, N_S)

dF13 <- merge(dF13, NCS)
dF13$st <-paste(dF13$N,"(", dF13$NS, ")")

### percentage conversion for text

dF13$cl_p<-(exp(dF13$cl)-1)*100
dF13$cu_p<-(exp(dF13$cu)-1)*100
dF13$mean_p<-(dF13$cl_p+dF13$cu_p)/2
dF13

dF13$EC <- factor(dF13$EC, levels = c("Leaf",
                                      "Litter",    
                                      "Root",     
                                      "Soil",   
                                      "Stem"),
                  labels = c("Leaf",
                             "Litter",    
                             "Root",     
                             "Soil",   
                             "Stem"))
setDT(dF13)
class(dF13)

ggplot(dF13[Ecosystem == "Pot"])+ geom_point(aes(x=EC, y=mean_p), shape=1,size=3.5)+
  geom_errorbar(aes(x=EC,ymin=cl_p, ymax=cu_p), width=0)+
  geom_text(aes(label=st,x=EC, y=-40,hjust=0), size=3)+
  coord_flip(ylim = c(-60, 80))+ scale_x_discrete(limits = rev(levels(dF5$EC)))+
  geom_hline(aes(yintercept=0),linetype="dashed",colour="black")+
  xlab("")+ylab("Effect size (%)") +
  theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                    panel.grid.minor = element_blank(),
                    panel.background = element_blank())+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  theme(legend.position="none")


######### Wetland #############
############ N #############

dF14 <-rbind(data.frame(t(confint(hmmNL_FG, method="Wald")[8,]), EC = "Leaf"),
             data.frame(t(confint(hmmNS_FG, method="Wald")[8,]), EC = "Soil"))
dF14$mean<-(dF14$X2.5..+dF14$X97.5..)/2
dF14 <- setNames(dF14, c("cl","cu", "EC", "mean"))

DT<-data.table(d1)
N_C<-DT[, .N, by=c("EC", "Ecosystem")]
N_S<-DT[, .(NS= length(unique(reference))), by = c("EC", "Ecosystem")]
NCS<-merge(N_C, N_S)

dF14 <- merge(dF14, NCS)
dF14$st <-paste(dF14$N,"(", dF14$NS, ")")

### percentage conversion for text

dF14$cl_p<-(exp(dF14$cl)-1)*100
dF14$cu_p<-(exp(dF14$cu)-1)*100
dF14$mean_p<-(exp(dF14$mean)-1)*100
dF14

dF14$EC <- factor(dF14$EC, levels = c("Leaf",
                                      "Soil"),
                  labels = c("Leaf",
                             "Soil"))
setDT(dF14)
class(dF14)

ggplot(dF14[Ecosystem == "Wetland"])+ geom_point(aes(x=EC, y=mean_p), shape=1,size=3.5)+
  geom_errorbar(aes(x=EC,ymin=cl_p, ymax=cu_p), width=0)+
  geom_text(aes(label=st,x=EC, y=-40,hjust=0), size=3)+
  coord_flip(ylim = c(-60, 80))+ scale_x_discrete(limits = rev(levels(dF5$EC)))+
  geom_hline(aes(yintercept=0),linetype="dashed",colour="black")+
  xlab("")+ylab("Effect size (%)") +
  theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                    panel.grid.minor = element_blank(),
                    panel.background = element_blank())+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  theme(legend.position="none")


############ P #############

dF15 <-rbind(data.frame(t(confint(hmmPL_FG, method="Wald")[8,]), EC = "Leaf"),
             data.frame(t(confint(hmmPS_FG, method="Wald")[8,]), EC = "Soil"))
dF15$mean<-(dF15$X2.5..+dF15$X97.5..)/2
dF15 <- setNames(dF15, c("cl","cu", "EC", "mean"))

DT<-data.table(d1)
N_C<-DT[, .N, by=c("EC", "Ecosystem")]
N_S<-DT[, .(NS= length(unique(reference))), by = c("EC", "Ecosystem")]
NCS<-merge(N_C, N_S)

dF15 <- merge(dF15, NCS)
dF15$st <-paste(dF15$N,"(", dF15$NS, ")")

### percentage conversion for text

dF15$cl_p<-(exp(dF15$cl)-1)*100
dF15$cu_p<-(exp(dF15$cu)-1)*100
dF15$mean_p<-(exp(dF15$mean)-1)*100
dF15

dF15$EC <- factor(dF15$EC, levels = c("Leaf",
                                      "Soil"),
                  labels = c("Leaf",
                             "Soil"))
setDT(dF15)
class(dF15)

ggplot(dF15[Ecosystem == "Wetland"])+ geom_point(aes(x=EC, y=mean_p), shape=1,size=3.5)+
  geom_errorbar(aes(x=EC,ymin=cl_p, ymax=cu_p), width=0)+
  geom_text(aes(label=st,x=EC, y=-40,hjust=0), size=3)+
  coord_flip(ylim = c(-60, 80))+ scale_x_discrete(limits = rev(levels(dF5$EC)))+
  geom_hline(aes(yintercept=0),linetype="dashed",colour="black")+
  xlab("")+ylab("Effect size (%)") +
  theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                    panel.grid.minor = element_blank(),
                    panel.background = element_blank())+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  theme(legend.position="none")


############ NP #############

dF16 <-rbind(data.frame(t(confint(hmmNPL_FG, method="Wald")[8,]), EC = "Leaf"),
             data.frame(t(confint(hmmNPS_FG, method="Wald")[6,]), EC = "Soil"))
dF16$mean<-(dF16$X2.5..+dF16$X97.5..)/2
dF16 <- setNames(dF16, c("cl","cu", "EC", "mean"))

DT<-data.table(d1)
N_C<-DT[, .N, by=c("EC", "Ecosystem")]
N_S<-DT[, .(NS= length(unique(reference))), by = c("EC", "Ecosystem")]
NCS<-merge(N_C, N_S)

dF16 <- merge(dF16, NCS)
dF16$st <-paste(dF16$N,"(", dF16$NS, ")")

### percentage conversion for text

dF16$cl_p<-(exp(dF16$cl)-1)*100
dF16$cu_p<-(exp(dF16$cu)-1)*100
dF16$mean_p<-(dF16$cl_p+dF16$cu_p)/2
dF16

dF16$EC <- factor(dF16$EC, levels = c("Leaf",
                                      "Soil"),
                  labels = c("Leaf",
                             "Soil"))
setDT(dF16)
class(dF16)

ggplot(dF16[Ecosystem == "Wetland"])+ geom_point(aes(x=EC, y=mean_p), shape=1,size=3.5)+
  geom_errorbar(aes(x=EC,ymin=cl_p, ymax=cu_p), width=0)+
  geom_text(aes(label=st,x=EC, y=80,hjust=0), size=3)+
  coord_flip(ylim = c(-60, 80))+ scale_x_discrete(limits = rev(levels(dF5$EC)))+
  geom_hline(aes(yintercept=0),linetype="dashed",colour="black")+
  xlab("")+ylab("Effect size (%)") +
  theme_bw()+ theme(axis.line = element_line(colour = "black"), panel.grid.major = element_blank(),
                    panel.grid.minor = element_blank(),
                    panel.background = element_blank())+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  theme(legend.position="none")


####### Full Fig. 5 #######
## use ggpubr package
all.data.Fig51 <- rbind(data.frame(dF5[Ecosystem == "Forest"], type = "Response of [N]"),
                       data.frame(dF6[Ecosystem == "Forest"], type = "Response of [P]"),
                       data.frame(dF7[Ecosystem == "Forest"], type = "Response of N:P"),
                       data.frame(dF8[Ecosystem == "Grassland"], type = "Response of [N]"),
                       data.frame(dF9[Ecosystem == "Grassland"], type = "Response of [P]"),
                       data.frame(dF10[Ecosystem == "Grassland"], type = "Response of N:P"))

ggplot(all.data.Fig51) + 
    geom_tile(aes(x = EC, y = rep(1:5, 6), fill = as.factor(rep(1:5, 6))), height = Inf, show.legend = F) +
    scale_fill_manual(values = c(rep("white", 3), rep("grey95", 2), "white", "grey95")) +
    geom_point(aes(x=EC, y=mean_p, color = (cu_p < 0 | cl_p > 0)), shape=15,size=3.5)+
    geom_text(aes(label=st,x=EC, y=70,hjust=0), size=3)+
    geom_errorbar(aes(x=EC,ymin=cl_p, ymax=cu_p, color = (cu_p < 0 | cl_p > 0)), width=0, size = 1)+
    scale_colour_manual(values = c("#a890a8", "#f0a860")) +
    guides(color = guide_legend(title = "Significance")) +
    coord_flip(ylim = c(-50, 90))+
    scale_x_discrete(limits = rev(levels(dF10$EC)))+
    geom_hline(aes(yintercept=0), linetype = 2, colour = "black", alpha = 0.5)+
    facet_grid(type ~ Ecosystem) +
    xlab("")+ylab("Effect size (%)") +
    theme_light() +
    theme(strip.text = element_text(face = "bold"),
          legend.position = "none")


all.data.Fig52 <- rbind(data.frame(dF5[Ecosystem == "Wetland"], type = "Response of [N]"),
                        data.frame(dF6[Ecosystem == "Wetland"], type = "Response of [P]"),
                        data.frame(dF7[Ecosystem == "Wetland"], type = "Response of N:P"))

ggplot(all.data.Fig52) + 
  geom_tile(aes(x = EC, y = rep(1:3, 3), fill = as.factor(rep(1:3, 3))), height = Inf, show.legend = F) +
  scale_fill_manual(values = c(rep("white", 3), rep("grey95", 2), "white", "grey95")) +
  geom_point(aes(x=EC, y=mean_p, color = (cu_p < 0 | cl_p > 0)), shape=15,size=3.5)+
  geom_text(aes(label=st,x=EC, y=70,hjust=0), size=3)+
  geom_errorbar(aes(x=EC,ymin=cl_p, ymax=cu_p, color = (cu_p < 0 | cl_p > 0)), width=0, size = 1)+
  scale_colour_manual(values = c("#a890a8", "#f0a860")) +
  guides(color = guide_legend(title = "Significance")) +
  coord_flip(ylim = c(-50, 90))+
  scale_x_discrete(limits = rev(levels(dF10$EC)))+
  geom_hline(aes(yintercept=0), linetype = 2, colour = "black", alpha = 0.5)+
  facet_grid(type ~ Ecosystem) +
  xlab("")+ylab("Effect size (%)") +
  theme_light() +
  theme(strip.text = element_text(face = "bold"),
        legend.position = "none")

all.data.Fig53 <- rbind(data.frame(dF11[Ecosystem == "Pot"], type = "Response of [N]"),
                        data.frame(dF12[Ecosystem == "Pot"], type = "Response of [P]"),
                        data.frame(dF13[Ecosystem == "Pot"], type = "Response of N:P"))

ggplot(all.data.Fig53) + 
  geom_tile(aes(x = EC, y = rep(1:4, 3), fill = as.factor(rep(1:4, 3))), height = Inf, show.legend = F) +
  scale_fill_manual(values = c(rep("white", 3), rep("grey95", 2), "white", "grey95")) +
  geom_point(aes(x=EC, y=mean_p, color = (cu_p < 0 | cl_p > 0)), shape=15,size=3.5)+
  geom_text(aes(label=st,x=EC, y=70,hjust=0), size=3)+
  geom_errorbar(aes(x=EC,ymin=cl_p, ymax=cu_p, color = (cu_p < 0 | cl_p > 0)), width=0, size = 1)+
  scale_colour_manual(values = c("#a890a8", "#f0a860")) +
  guides(color = guide_legend(title = "Significance")) +
  coord_flip(ylim = c(-50, 90))+
  scale_x_discrete(limits = rev(levels(dF10$EC)))+
  geom_hline(aes(yintercept=0), linetype = 2, colour = "black", alpha = 0.5)+
  facet_grid(type ~ Ecosystem) +
  xlab("")+ylab("Effect size (%)") +
  theme_light() +
  theme(strip.text = element_text(face = "bold"),
        legend.position = "none")










############### Fig. 6 ######
############ MAT ###############
############## N ##############
########## leaf #############
hmmNL_T<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAT) + (1|reference), weights = Wi_N,dL)
summary(hmmNL_T)
dL$N_L_MAT<-resid(hmmNL_T)+fixef(hmmNL_T)[1]+fixef(hmmNL_T)[3]*scale(dL$MAT)
Fig.6a <- ggplot(data = dL, aes(x = MAT, y = N_L_MAT)) +
  geom_point(aes(size=Wi_N),shape = 1) +
  stat_smooth(method = lm, size = 0.8) +
  ylab("LnRR of leaf [N]") + 
  xlab("MAT (℃)") + 
  geom_hline(aes(yintercept = 0),linetype="dashed",colour="black") +
  theme_bw() +annotate("text",x = 15, y = 1.2,label = "P = 0.01",col="red",fontface="bold.italic")
########## Stem #############
hmmNST_T<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAT) + (1|reference), weights = Wi_N,dST)
summary(hmmNST_T)
########## Root #############
hmmNR_T<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAT) + (1|reference), weights = Wi_N,dR)
summary(hmmNR_T)
########## litter #############
hmmNLi_T<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAT) + (1|reference), weights = Wi_N,dLi)
summary(hmmNLi_T)
########## soil #############
hmmNS_T<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAT) + (1|reference), weights = Wi_N,dS)
summary(hmmNS_T)
dS$N_S_MAT<-resid(hmmNS_T)+fixef(hmmNS_T)[1]+fixef(hmmNS_T)[3]*scale(dS$MAT)
Fig.6b <- ggplot(data = dS, aes(x = MAT, y = N_S_MAT)) +
  geom_point(aes(size=Wi_N),shape = 1) +
  stat_smooth(method = lm, size = 0.8) +
  ylab("LnRR of soil [N]") + 
  xlab("MAT (℃)") + 
  geom_hline(aes(yintercept = 0),linetype="dashed",colour="black") +
  theme_bw() +annotate("text",x = 20, y = 1.2,label = "P < 0.01",col="red",fontface="bold.italic")

############## P ##############
########## leaf #############
hmmPL_T<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAT) + (1|reference), weights = Wi_P,dL)
summary(hmmPL_T)
########## Stem #############
hmmPST_T<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAT) + (1|reference), weights = Wi_P,dST)
summary(hmmPST_T)
########## Root #############
hmmPR_T<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAT) + (1|reference), weights = Wi_P,dR)
summary(hmmPR_T)
dR$P_R_MAT<-resid(hmmPR_T)+fixef(hmmPR_T)[1]+fixef(hmmPR_T)[3]*scale(dR$MAT)
Fig.6c <- ggplot(data = dR, aes(x = MAT, y = P_R_MAT)) +
  geom_point(aes(size=Wi_N),shape = 1) +
  stat_smooth(method = lm, size = 0.8) +
  ylab("LnRR of root [P]") + 
  xlab("MAT (℃)") + 
  geom_hline(aes(yintercept = 0),linetype="dashed",colour="black") +
  theme_bw() +annotate("text",x = 15, y = 1.2,label = "P = 0.02",col="red",fontface="bold.italic")
########## litter #############
hmmPLi_T<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAT) + (1|reference), weights = Wi_P,dLi)
summary(hmmPLi_T)
########## soil #############
hmmPS_T<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAT) + (1|reference), weights = Wi_P,dS)
summary(hmmPS_T)
dS$P_S_MAT<-resid(hmmPS_T)+fixef(hmmPS_T)[1]+fixef(hmmPS_T)[3]*scale(dS$MAT)
Fig.6d <- ggplot(data = dS, aes(x = MAT, y = P_S_MAT)) +
  geom_point(aes(size=Wi_N),shape = 1) +
  stat_smooth(method = lm, size = 0.8) +
  ylab("LnRR of soil [P]") + 
  xlab("MAT (℃)") + 
  geom_hline(aes(yintercept = 0),linetype="dashed",colour="black") +
  theme_bw() +annotate("text",x = 15, y = 1.2,label = "P = 0.01",col="red",fontface="bold.italic")
############## NP ##############
########## leaf #############
hmmNPL_T<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAT) + (1|reference), weights = Wi_NP,dL)
summary(hmmNPL_T)
########## Stem #############
hmmNPST_T<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAT) + (1|reference), weights = Wi_NP,dST)
summary(hmmNPST_T)
########## Root #############
hmmNPR_T<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAT) + (1|reference), weights = Wi_NP,dR)
summary(hmmNPR_T)
########## litter #############
hmmNPLi_T<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAT) + (1|reference), weights = Wi_NP,dLi)
summary(hmmNPLi_T)
########## soil #############
hmmNPS_T<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAT) + (1|reference), weights = Wi_NP,dS)
summary(hmmNPS_T)


############ MAP ###############
############## N ##############
########## leaf #############
hmmNL_P<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAP) + (1|reference), weights = Wi_N,dL)
summary(hmmNL_P)
########## Stem #############
hmmNST_P<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAP) + (1|reference), weights = Wi_N,dST)
summary(hmmNST_P)
########## Root #############
hmmNR_P<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAP) + (1|reference), weights = Wi_N,dR)
summary(hmmNR_P)
########## litter #############
hmmNLi_P<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAP) + (1|reference), weights = Wi_N,dLi)
summary(hmmNLi_P)
########## soil #############
hmmNS_P<-lmer(yi_N~scale(log(N))+scale(ED)+scale(MAP) + (1|reference), weights = Wi_N,dS)
summary(hmmNS_P)
############## P ##############
########## leaf #############
hmmPL_P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAP) + (1|reference), weights = Wi_P,dL)
summary(hmmPL_P)
########## Stem #############
hmmPST_P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAP) + (1|reference), weights = Wi_P,dST)
summary(hmmPST_P)
########## Root #############
hmmPR_P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAP) + (1|reference), weights = Wi_P,dR)
summary(hmmPR_P)
########## litter #############
hmmPLi_P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAP) + (1|reference), weights = Wi_P,dLi)
summary(hmmPLi_P)
########## soil #############
hmmPS_P<-lmer(yi_P~scale(log(N))+scale(ED)+scale(MAP) + (1|reference), weights = Wi_P,dS)
summary(hmmPS_P)
############## NP ##############
########## leaf #############
hmmNPL_P<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAP) + (1|reference), weights = Wi_NP,dL)
summary(hmmNPL_P)
########## Stem #############
hmmNPST_P<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAP) + (1|reference), weights = Wi_NP,dST)
summary(hmmNPST_P)
########## Root #############
hmmNPR_P<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAP) + (1|reference), weights = Wi_NP,dR)
summary(hmmNPR_P)
dR$NP_R_MAP<-resid(hmmNPR_P)+fixef(hmmNPR_P)[1]+fixef(hmmNPR_P)[3]*scale(dR$MAP)
Fig.6e <- ggplot(data = dR, aes(x = MAP, y = NP_R_MAP)) +
  geom_point(aes(size=Wi_N),shape = 1) +
  stat_smooth(method = lm, size = 0.8) +
  ylab("LnRR of root [NP]") + 
  xlab("MAP (mm)") + 
  geom_hline(aes(yintercept = 0),linetype="dashed",colour="black") +
  theme_bw() +
  annotate("text",x = 2250, y = 1,label = "P = 0.02",col="red",fontface="bold.italic")
########## litter #############
hmmNPLi_P<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAP) + (1|reference), weights = Wi_NP,dLi)
summary(hmmNPLi_P)
########## soil #############
hmmNPS_P<-lmer(yi_NP~scale(log(N))+scale(ED)+scale(MAP) + (1|reference), weights = Wi_NP,dS)
summary(hmmNPS_P)
#all Figure 6
Figure6 <-ggarrange(Fig.6a,Fig.6b,
                     Fig.6c,Fig.6d,Fig.6e,
                     nrow=3,ncol=2,labels = c("a","b","c","d","e")) 

Figure6




############### over all effects of Ecosystem ##########

############## N ##############
########## leaf #############
BNL<-lmer(yi_N~scale(log(N))+scale(log (ED))+Ecosystem + (1|reference), weights = Wi_N,dL)
anova(BNL)
########## stem #############
BNST<-lmer(yi_N~scale(log(N))+scale(log (ED))+Ecosystem + (1|reference), weights = Wi_N,dST)
anova(BNST)
########## ROOT #############
BNR<-lmer(yi_N~scale(log(N))+scale(log (ED))+Ecosystem + (1|reference), weights = Wi_N,dR)
anova(BNR)
########## Litter #############
BNLi<-lmer(yi_N~scale(log(N))+scale(log (ED))+Ecosystem + (1|reference), weights = Wi_N,dLi)
anova(BNLi)
########## Soil #############
BNS<-lmer(yi_N~scale(log(N))+scale(log (ED))+Ecosystem + (1|reference), weights = Wi_N,dS)
anova(BNS)


############## P ##############
########## leaf #############
BPL<-lmer(yi_P~scale(log(N))+scale(log (ED))+Ecosystem + (1|reference), weights = Wi_P,dL)
anova(BPL)
########## stem #############
BPST<-lmer(yi_P~scale(log(N))+scale(log (ED))+Ecosystem + (1|reference), weights = Wi_P,dST)
anova(BPST)
########## ROOT #############
BPR<-lmer(yi_P~scale(log(N))+scale(log (ED))+Ecosystem + (1|reference), weights = Wi_P,dR)
anova(BPR)
########## Litter #############
BPLi<-lmer(yi_P~scale(log(N))+scale(log (ED))+Ecosystem + (1|reference), weights = Wi_P,dLi)
anova(BPLi)
########## Soil #############
BPS<-lmer(yi_P~scale(log(N))+scale(log (ED))+Ecosystem + (1|reference), weights = Wi_P,dS)
anova(BPS)


############## NP ##############
########## leaf #############
BNPL<-lmer(yi_NP~scale(log(N))+scale(log (ED))+Ecosystem + (1|reference), weights = Wi_NP,dL)
anova(BNPL)
########## stem #############
BNPST<-lmer(yi_NP~scale(log(N))+scale(log (ED))+Ecosystem + (1|reference), weights = Wi_NP,dST)
anova(BNPST)
########## ROOT #############
BNPR<-lmer(yi_NP~scale(log(N))+scale(log (ED))+Ecosystem + (1|reference), weights = Wi_NP,dR)
anova(BNPR)
########## Litter #############
BNPLi<-lmer(yi_NP~scale(log(N))+scale(log (ED))+Ecosystem + (1|reference), weights = Wi_NP,dLi)
anova(BNPLi)
########## Soil #############
BNPS<-lmer(yi_NP~scale(log(N))+scale(log (ED))+Ecosystem + (1|reference), weights = Wi_NP,dS)
anova(BNPS)














